/**
 * @fileOverview This file redirects the user to the Committee or Investigator activity page, depending on their
 *               permissions and the menu option chosen. The user selects the menu option which redirects them the
 *               committeeSwapper page that holds this script. The code looks at the users security groups and
 *               determines if they belong to more than one facility. If they only belong to one facility, they are
 *               redirected there immediately. If they belong to more than one facility they are given a list of
 *               facilities to go to. finally if they do not have access to a facility, they are givene an errror
 *               message. In some cases the jshint errors are suppressed with jshint -W### codes, jshint globals, or
 *               jshint exported comments
 * @version 2.3.0
 */
// JSHINT globals declaration so references to these global variables do not get flagged as warning.
/* globals RAMS, location */
// NOTUSED
// var groupPartNames = [];
var committeeAction = getParamValue('committeeAction');

/**
 * associative array of committees from the Committee List, indexed by Title. Value is the Committee object.
 * 
 * @type {committees[]}
 */
var committeesItems = [];

/**
 * associative array of committees from the Committee List, indexed by Title. Value is the Facility object.
 * 
 * @type {committees[]}
 */

/**
 * associative array of facilities from the Facility List, indexed by Title. Value is the Facility object.
 * 
 * @type {facilities[]}
 */
var facilitiesItems = [];
var facilities = {};
var facilitiesLen = 0;
var fCount = 0;
var mCount = 0;
var potentialGroups = {};
var isMember = function(gid) {
   return potentialGroups[gid];
};

var matches = [];

if (committeeAction == "committeeActivities") {
   $(document).ready(changeCommitteeLink());
} else if (committeeAction == "investigatorActivities") {
   $(document).ready(changeInvestigatorsLink());
} else {
   $(document).ready(changeCommitteeLink());
}

function getParamValue(param) {
   var urlParamString = location.search.split(param + "=");
   if (urlParamString.length <= 1) {
      return "";
   } else {
      var tmp = urlParamString[1].split("&");
      return tmp[0];
   }
}

function changeCommitteeLink() {
   var currentUserId;
   var fDone = false;

   var currentUrl = RAMS.Environment.SharePoint.URL;
   // NOT USED
   // var groupPart = "";

   restCall(currentUrl + "_api/Web/CurrentUser", function(currentUser) {
      currentUserId = currentUser.d.Id;
      // get the list of user groups that the current user belongs to
      restCall(currentUrl + "_api/Web/CurrentUser/Groups", function(returnedGroups) {
         returnedGroups = returnedGroups.d.results;

         for (var i = 0; i < returnedGroups.length; i++) {
            potentialGroups[returnedGroups[i].Id] = true;
         }

         restCall(currentUrl + "_api/Web/lists/GetByTitle('Facilities')/Items", function(facJson) {
            var f;
            facilities = facJson.d.results;
            facilitiesLen = facilities.length;
            for (var j = 0; j < facilities.length; j++) {
               f = facilities[j];
               if (facilities.length == j) {
                  fDone = true;
               }
               var title = f.Title;
               // add each user the the facilities associative array
               facilitiesItems[title] = f;
               if ((isMember(f.LocalSiteAdministratorsId)) || (isMember(f.LocalSiteLiaisonsId))
                  || (isMember(f.AdministrativeOfficersId)) || (isMember(f.AnimalFacilityManagersId))
                  || (isMember(f.ResearchComplianceOfficersId)) || (f.FacilityLiaisonId == currentUserId)) {
                  matches[f.Title] = f;
                  matches.push(f);
                  mCount++;
                  // matches.push(f);
               }

               getCommittees(facilities[j].ID, currentUrl);
            }
         });
      });
   });
}

function getCommittees(fId, currentUrl) {
   // _api/Web/lists/GetByTitle('Committees')/Items
   // +
   // "?$select=ID,FacilitiesLookup/ID,FacilitiesLookup/Title,CommitteeType/ID,CommitteeType/CommitteesName,CommitteeType/CommitteeCode,CommitteeType/RoutingRuleDescription,*"
   // + "&$expand=FacilitiesLookup,CommitteeType"
   // + "&$filter=(FacilitiesLookup/ID eq 5)"

   var comUrl = currentUrl
      + "_api/Web/lists/GetByTitle('Committees')/Items"
      + "?$select=ID,FacilitiesLookup/ID,FacilitiesLookup/Title,CommitteesLookup/ID,CommitteesLookup/CommitteesName,CommitteesLookup/CommitteeCode,CommitteesLookup/RoutingRuleDescription,*"
      + "&$expand=FacilitiesLookup,CommitteesLookup" + "&$filter=(FacilitiesLookup/ID eq " + fId + ")";
   restCall(
      comUrl,
      function(committees) {
         fCount++;
         var c;
         committees = committees.d.results;
         for (var k = 0; k < committees.length; k++) {
            c = committees[k];
            var title = c.Title;
            // add each user the the committees associative array
            committeesItems[title] = c;
            if ((c.DelegatedId === null || c.DelegatedId <= 0)
               && !(c.Hidden)
               && ((isMember(c.AdministratorsId)) || (isMember(c.CommitteeCoordinatorsId)) || (isMember(c.CommitteeMembersId)))) {
               if (!matches[c.FacilitiesLookup.Title]) {
                  matches[c.FacilitiesLookup.Title] = facilitiesItems[c.FacilitiesLookup.Title];
                  matches.push(facilitiesItems[c.FacilitiesLookup.Title]);
                  mCount++;
                  // matches.push(c.FacilitiesLookup.Title);
               }
            }
         }

         if (facilitiesLen === fCount) {
            var facilityLookup = "";
            var multi = false;
            // NOT USED
            // var facilitySite = "";
            if (mCount == 1) {
               multi = false;
               facilityLookup = matches[0].FacilitySubsite.Url;
               facilityLookup = (facilityLookup.substr(facilityLookup.lastIndexOf('/') + 1));
               getGroupPartName(currentUrl, matches[0].UsersId, matches[0], multi);
            } else if (mCount === 0) {
               $(document.body)
                  .append("<em>You are not a member of any of the site groups in the Committee List.</em>");
            } else {
               multi = true;
               $(document.body).append(
                  "<p><em>You are a group member within several sites on the Committee List:</em></p>");
               matches.sort(function(a, b) {
                  return (a.Title > b.Title) ? 1 : ((b.Title > a.Title) ? -1 : 0);
               });
               for (var i = 0; i < matches.length; i++) {
                  getGroupPartName(currentUrl, matches[i].UsersId, matches[i], multi);
               }
            }
         }
      });
}
function restCall(endpoint, callback) {
   jQuery.ajax({
      url : endpoint,
      type : "GET",
      headers : {
         "accept" : "application/json; odata=verbose"
      }
   }).done(function(returnedJson) {
      callback(returnedJson);
   });
}

function getGroupPartName(currentUrl, usersId, match, multi) {
   restCall(currentUrl + "_api/Web/SiteGroups(" + usersId + ")",
      function(title) {
         var facilityLookup = "";
         var facilitySite = "";

         if (!multi) {
            facilityLookup = match.FacilitySubsite.Url;
            facilityLookup = (facilityLookup.substr(facilityLookup.lastIndexOf('/') + 1));
         }

         var userGroupTitle = title.d.Title;
         var lastIndex = userGroupTitle.lastIndexOf(" ");
         var groupPartName = userGroupTitle.substring(0, lastIndex);
         if (multi) {
            facilityLookup = match.FacilitySubsite.Url;
            facilityLookup = (facilityLookup.substr(facilityLookup.lastIndexOf('/') + 1));

            if (committeeAction == "committeeActivities") {
               $(document.body).append(
                  "<a href='" + "../SitePages/FacilityHome.html?facilityName=" + facilityLookup + "&facilityTitle="
                     + match.Title + "&groupPart=" + groupPartName + "'>" + match.Title + "</a><br/>");
            } else if (committeeAction == "investigatorActivities") {
               $(document.body).append(
                  "<a href='" + "../SitePages/InvestigatorActivities.html?facilityName=" + facilityLookup
                     + "&facilityTitle=" + match.Title + "&groupPart=" + groupPartName + "'>" + match.Title
                     + "</a><br/>");
            }
            // If someone does not update a link with the parameters specified we want to default to the Facility page
            else {
               $(document.body).append(
                  "<a href='" + "../SitePages/FacilityHome.html?facilityName=" + facilityLookup + "&facilityTitle="
                     + match.Title + "&groupPart=" + groupPartName + "'>" + match.Title + "</a><br/>");
            }
         } else {
            if (committeeAction == "committeeActivities") {
               facilitySite = "../SitePages/FacilityHome.html?facilityName=" + facilityLookup + "&facilityTitle="
                  + match.Title + "&groupPart=" + groupPartName;
               window.location.replace(facilitySite);
            } else if (committeeAction == "investigatorActivities") {
               facilitySite = "../SitePages/InvestigatorActivities.html?facilityName=" + facilityLookup
                  + "&facilityTitle=" + match.Title + "&groupPart=" + groupPartName;
               window.location.replace(facilitySite);
            }
            // If someone does not update a link with the parameters specified we want to default to the Facility page
            else {
               facilitySite = "../SitePages/FacilityHome.html?facilityName=" + facilityLookup + "&facilityTitle="
                  + match.Title + "&groupPart=" + groupPartName;
               window.location.replace(facilitySite);
            }
         }
      });
}

function changeInvestigatorsLink() {
   var potentialGroups = {};
   var isMember = function(gid) {
      return potentialGroups[gid];
   };
   var currentUrl = RAMS.Environment.SharePoint.URL;
   // NOT USED
   // var groupPart = "";
   restCall(currentUrl + "_api/Web/CurrentUser/Groups", function(returnedGroups) {
      var i;
      returnedGroups = returnedGroups.d.results;

      // This loop builds an associative array with Ids of the security groups that the user belongs to.
      for (i = 0; i < returnedGroups.length; i++) {
         potentialGroups[returnedGroups[i].Id] = true;
      }

      // Retrieve the list of facilities and for each facility, see if the Users security group id is in the list of
      // potential groups, meaning the user belongs to that facility.
      restCall(currentUrl + "_api/Web/lists/GetByTitle('Facilities')/Items", function(facilities) {
         var f, matches = [];
         facilities = facilities.d.results;
         for (i = 0; i < facilities.length; i++) {
            f = facilities[i];
            var title = f.Title;
            // add each user the the facilities associative array
            facilitiesItems[title] = f;
            if (isMember(f.UsersId)) {
               matches.push(f);
            }
         }

         // for ( var key in facilitiesItems) {
         // var facilityItem = facilitiesItems[key];
         // if (isMember(facilityItem.UsersId)) {
         // matches.push(facilityItem);
         // }
         // }

         var facilityLookup = "";
         var multi = false;
         // NOT USED
         // var facilitySite = "";
         if (matches.length == 1) {
            multi = false;
            facilityLookup = matches[0].FacilitySubsite.Url;
            facilityLookup = (facilityLookup.substr(facilityLookup.lastIndexOf('/') + 1));
            getGroupPartName(currentUrl, matches[0].UsersId, matches[0], multi);
         } else if (matches.length === 0) {
            $(document.body).append(
               "<em>You are not a member of any of the site user groups in the Facilities List.</em>");
         } else {
            multi = true;
            $(document.body).append(
               "<p><em>You are a user group member within several sites on the Facilities List:</em></p>");
            for (i = 0; i < matches.length; i++) {
               getGroupPartName(currentUrl, matches[i].UsersId, matches[i], multi);
            }
         }
      });
   });
}
