<#
.SYNOPSIS
	Add Application Site Columns For Committees to the Site Collection.
    
.DESCRIPTION
	This creates the Application Site Columns For Committees and Adds Them To The Application Content Types.  
        
.EXAMPLE
	#when run from deploymentDriver.ps1
	Run-Script 180 AddApplicationSiteColumnsForCommittees.ps1

.EXAMPLE
	#when run from the powershell command prompt.
	.\AddApplicationSiteColumnsForCommittees.ps1
 #>
$weburl = Get-SiteURL
$webSite = Get-SiteWeb

$Committees = @("IACUC", "IRB", "RDC", "SRS", "SC1", "SC2", "SC3")

$AdministratorDN = "Administrator;User"
$PrimaryReviewerDN = "Primary Reviewer;User"
$ReviewersDN = "Reviewers;User"
$SubmitDateDN = "Submit Date;Date"
$ApprovedDateDN = "Approved Date;Date"
$ExpiresDateDN = "Expires Date;Date"
$TriennialReviewDateDN = "Triennial Review Date;Date"
$StatusDN = "Status;Choice"
$ReviewRequiredDN = "Review Required;Boolean"
$ApprovalEmailBrokerSentDN = "Approval Email Broker Sent;Boolean"

$ALColumns = @($AdministratorDN, $PrimaryReviewerDN, $ReviewersDN, $SubmitDateDN, $ApprovedDateDN, $ExpiresDateDN, $TriennialReviewDateDN, $StatusDN, $ReviewRequiredDN, $ApprovalEmailBrokerSentDN)

$separator = ";"
$option = [System.StringSplitOptions]::RemoveEmptyEntries

#CREATE SITE COLUMNS
write-log -message "CREATING SITE COLUMNS AND ADDING THEM TO CONTENT TYPE" -consoleForeground Green

foreach($com in $Committees) {
    foreach($column in $ALColumns) {
        $scDN,$scType = $column.split($separator,$option)
        $scDN = $com + " " + $scDN
        $scIN = $scDN.replace(" ","")
        if($scType -eq "Choice") {
            Set-SiteColumnLookup -web $webSite -colName $scDN -colStaticName $scIN -lookupListName "CommitteeStatus" -lookupColumnName "Title" 
        } elseif ($scType -eq "Boolean") {
            Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName $scDN -sFieldStaticName $scIN -sFieldInternalName $scIN -sFieldType $scType  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm
        } else {
            if($scDN -match "Reviewers") {
                #Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName $scDN -sFieldStaticName $scIN -sFieldInternalName $scIN -sFieldType $scType  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm -allowMultipleValues -defaultValue "false"
                Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName $scDN -sFieldStaticName $scIN -sFieldInternalName $scIN -sFieldType $scType  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm -allowMultipleValues
                }
            else {
                Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName $scDN -sFieldStaticName $scIN -sFieldInternalName $scIN -sFieldType $scType  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm
               }
        }
        Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName $scIN -sFieldStaticName $scIN
        write-log -message "Created site column $scDN, $scIN with type:$scType to RAMS IRB and added it to Application CT" -consoleForeground Green
    }
}
Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "FacilityLookup" -sFieldStaticName "FacilityLookup"

#Add Triennial Review Date
Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName "Triennial Review  Date" -sFieldStaticName "TriennialReviewDate" -sFieldInternalName "TriennialReviewDate" -sFieldType DateTime  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm
Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "TriennialReviewDate" -sFieldStaticName "TriennialReviewDate"

#add sent related columns
Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName "Submit Email Broker Sent" -sFieldStaticName "SubmitEmailBrokerSent" -sFieldInternalName "SubmitEmailBrokerSent" -sFieldType Boolean  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm -defaultValue "false"
Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName "Approval Email Broker Sent" -sFieldStaticName "ApprovalEmailBrokerSent" -sFieldInternalName "ApprovalEmailBrokerSent" -sFieldType Boolean  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm -defaultValue "false"
Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName "Approval RDC Email Broker Sent" -sFieldStaticName "ApprovalRDCEmailBrokerSent" -sFieldInternalName "ApprovalRDCEmailBrokerSent" -sFieldType Boolean  -spFieldGroup "RAMS IRB" -showInEditForm -showInNewForm -defaultValue "false"
Set-SiteColumn -web (Get-SiteWeb) -sFieldDisplayName "Committee Broker Directive" -sFieldStaticName "CommitteeBrokerDirective" -sFieldInternalName "CommitteeBrokerDirective" -sFieldType "Text"  -spFieldGroup "RAMS IRB" 

Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "SubmitEmailBrokerSent" -sFieldStaticName "SubmitEmailBrokerSent"
Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "ApprovalEmailBrokerSent" -sFieldStaticName "ApprovalEmailBrokerSent"
Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "ApprovalRDCEmailBrokerSent" -sFieldStaticName "ApprovalRDCEmailBrokerSent"
Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "CommitteeBrokerDirective" -sFieldStaticName "CommitteeBrokerDirective"

$webSite = Get-SiteWeb
$webSite.Update()
$webSite = Get-SiteWeb
