<#
.SYNOPSIS
    Creates the AF Document Library for each Facility and deletes it if it exists.
    
.DESCRIPTION
    This creates the AF Document Library for each Facility and deletes it if it exists.  
        
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 110 CreateAFDocumentLibrary.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\CreateAFDocumentLibrary.ps1
 #>

function GetAllWebs($url) {
<#
.SYNOPSIS
    This function loops through all subsites.
    
.DESCRIPTION
    This function loops through all subsites and calls Deletes and creates document library for each subsite.  
        
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 110 CreateAFDocumentLibrary.ps1
 #>
Add-PSSnapin Microsoft.SharePoint.Powershell

    try {
        write-log -message "$([String]::Format("Procesing web {0}",$w.Url))" -consoleForeground Cyan
        if($w.Webs.Count -gt 0) {
            foreach($web in $w.Webs) {
              DeleteAFDocumentLibrary $web;
              CreateAFDocumentLibrary $web;
            }
        }
    } catch {
        write-log -message "$([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message))" -consoleForeground Red
        if ($($_.Exception.ErrorRecord)) { write-log -message "$($_.Exception.ErrorRecord)" -consoleForeground Red }
        if ($($_.Exception.stacktrace)) { write-log -message "$($_.Exception.stacktrace)" -consoleForeground Red }
        if ($($_.ScriptStackTrace)) { write-log -message "$($_.ScriptStackTrace)" -consoleForeground Red }
        
    }   
}

function DeleteAFDocumentLibrary($web) {
<#
.SYNOPSIS
	This function deletes the AF Document Library.
    
.DESCRIPTION
	This function creates the AF document Library for each subsite.

.EXAMPLE
	#when run from the powershell command prompt.
	 DeleteAFDocumentLibrary $web ($web of subsite)
 #>

  $list = $web.Lists.TryGetList("AF Documents")
    if($list -ne $null) {
        # The list already exists
        $ListToDeleteName = "AF Documents"
 
        #Get Web and List objects
        $list = $web.Lists[$ListToDeleteName]
    
        #Reset the "Allow Deletion" Flag
        $list.AllowDeletion = $true
       
        $list.Update()
        $list.Delete()
        write-log -message "Deleted Animal Facility Document $ListToDeleteName Library on $($web.url)" -consoleForeground Yellow
    }    
}

function CreateAFDocumentLibrary($web) {
<#
.SYNOPSIS
	This function creates the AF Document Library.
    
.DESCRIPTION
	This function creates the AF document Library for each subsite.

.EXAMPLE
	#when run from the powershell command prompt.
	 CreateAFDocumentLibrary $web ($web of subsite)
 #>
    $SPTemplate = [Microsoft.Sharepoint.SPListTemplateType]::DocumentLibrary
    $web.Lists.Add("AFDocuments","AFDocuments",$SPTemplate)

    $list = $web.Lists.TryGetList("AFDocuments")

    if($list -ne $null) {
        $list.Title="Animal Facility Documents"
        $list.Update()
        write-log -message "Animal Facility Document Library $($list.Title) is created on $($web.url)" -consoleForeground Green
    } else {
        write-log -message "Could not create Animal Facility Document Library on $($web.url)" -consoleForeground Red
    }
}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://DNS.URL/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
GetAllWebs($siteUrl)