<#
.SYNOPSIS
	Create Committees List View.
    
.DESCRIPTION
	This creates the Committees List and adds to Committees CT.  

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script CreateCommitteesList.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\CreateCommitteesList.ps1   
 #>

Add-PSSnapin Microsoft.SharePoint.PowerShell

if ((get-module | Where-Object({$_.Name -eq 'RAMS_Module_Util'}) ) -eq $null) {
    Import-Module .\RAMS_Module_Util.psm1 -Verbose
}
$weburl = Get-SiteURL
$webSite = Get-SPWeb $weburl

#CREATE SITE COLUMNS
write-log -message "CREATING SITE COLUMNS" -consoleForeground Green

$committeeFacilityLookupDN = "Facility" # Do we want to call the display name something different from the internal name?
$committeeFacilityLookupIN = "FacilityLookup"
$committeeTypeDN = "Type"
$committeeTypeIN = "Type"
$committeeNameDN = "Name"
$committeeNameIN = "Name"
$committeeAcronymDN = "Acronym"
$committeeAcronymIN = "Acronym"
# Local Site Administrators is a Display Name Change from Facility Administrators
$committeeAdministratorDN = "Administrators"
$committeeAdministratorsIN = "Administrators"
$committeeCoordinatorsDN = "Committee Coordinators"
$committeeCoordinatorsIN = "CommitteeCoordinators"
$committeeMembersDN = "Committee Members"
$committeeMembersIN = "CommitteeMembers"
$committeeDelegatedToDN = "Delegated To"
$committeeDelegatedToIN = "DelegatedTo"
$committeeHiddenDN = "Hidden"
$committeeHiddenIN = "Hidden"

$committeeContentType = "Committees CT"

$committeesListNameDN = "Committees"
$committeesListNameIN = "Committees"

# TODO - CHITA - verify fieldTypes 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeFacilityLookupDN -sFieldStaticName $committeeFacilityLookupIN -sFieldInternalName $committeeFacilityLookupIN -sFieldType "Lookup"  -spFieldGroup "RAMS IRB" 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeTypeDN -sFieldStaticName $committeeTypeIN -sFieldInternalName $committeeTypeIN -sFieldType "Lookup"  -spFieldGroup "RAMS IRB" 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeNameDN -sFieldStaticName $committeeNameIN -sFieldInternalName $committeeNameIN -sFieldType "Text"  -spFieldGroup "RAMS IRB" 
# TODO - CHITA - can we specify the length of the text field? Acronym should be < 20 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeAcronymDN -sFieldStaticName $committeeAcronymIN -sFieldInternalName $committeeAcronymIN -sFieldType "Text"  -spFieldGroup "RAMS IRB" 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeAdministratorDN -sFieldStaticName $committeeAdministratorsIN -sFieldInternalName $committeeAdministratorsIN -sFieldType "User"  -spFieldGroup "RAMS IRB" 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeCoordinatorsDN -sFieldStaticName $committeeCoordinatorsIN -sFieldInternalName $committeeCoordinatorsIN -sFieldType "User"  -spFieldGroup "RAMS IRB" 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeMembersDN -sFieldStaticName $committeeMembersIN -sFieldInternalName $committeeMembersIN -sFieldType "User"  -spFieldGroup "RAMS IRB" 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeDelegatedToDN -sFieldStaticName $committeeDelegatedToIN -sFieldInternalName $committeeDelegatedToIN -sFieldType "Lookup"  -spFieldGroup "RAMS IRB" 
Set-SiteColumn -web $webSite -sFieldDisplayName $committeeHiddenDN -sFieldStaticName $committeeHiddenIN -sFieldInternalName $committeeHiddenIN -sFieldType "Boolean"  -spFieldGroup "RAMS IRB" 

#ADD SITE COLUMNS TO CONTENT TYPE
write-log -message "ADDING SITECOLUMNS TO CONTENT TYPE" -consoleForeground Green
# TODO - CHITA - Need to add FieldRequired attribute, default to false if not provided.
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeFacilityLookupIN -sFieldStaticName $committeeFacilityLookupIN -sFieldRequired $true
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeTypeIN -sFieldStaticName $committeeTypeIN -sFieldRequired $true # Should be unique per facility
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeNameIN -sFieldStaticName $committeeNameIN -sFieldRequired $true
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeAcronymIN -sFieldStaticName $committeeAcronymIN -sFieldRequired $true
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeAdministratorsIN -sFieldStaticName $committeeAdministratorsIN -sFieldRequired $true
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeCoordinatorsIN -sFieldStaticName $committeeCoordinatorsIN -sFieldRequired $true
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeMembersIN -sFieldStaticName $committeeMembersIN -sFieldRequired $true
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeDelegatedToIN -sFieldStaticName $committeeDelegatedToIN -sFieldRequired $false
Add-SiteColumnToCT -web $webSite -ctName $committeeContentType -sFieldInternalName $committeeHiddenIN -sFieldStaticName $committeeHiddenIN -sFieldRequired $true # should default to value of false

#ADD SITE COLUMNS TO CONTENT TYPE
write-log -message "CREATING FACILITIES LIST" -consoleForeground Green
Add-List -web $webSite 
# ID, Target Audience, Created, Created By, Modified, and Modified By are standard SP columns
Add-SiteColumnToList -web $webSite -sFieldInternalName "ID"
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeFacilityLookupIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeTypeIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeNameIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeAcronymIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeAdministratorsIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeCoordinatorsIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeMembersIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeDelegatedToIN
Add-SiteColumnToList -web $webSite -sFieldInternalName $committeeHiddenIN
Add-SiteColumnToList -web $webSite -sFieldInternalName "Target Audiences"
Add-SiteColumnToList -web $webSite -sFieldInternalName "Created"
Add-SiteColumnToList -web $webSite -sFieldInternalName "Created By"
Add-SiteColumnToList -web $webSite -sFieldInternalName "Modified"
Add-SiteColumnToList -web $webSite -sFieldInternalName "Modified By"

#Create List Views and Detail Forms
write-log -message "CREATING FACILITIES LIST VIEW" -consoleForeground Green
# TODO - CHITA - Create All Items View in field order shown above

write-log -message "CREATING FACILITIES NEW DETAIL FORM" -consoleForeground Green
# TODO - CHITA - Create new Forms in field order shown above

write-log -message "CREATING FACILITIES EDIT DETAIL FORM" -consoleForeground Green

write-log -message "CREATING FACILITIES DISPLAY DETAIL FORM" -consoleForeground Green

# TODO CHITA - Migrate Data from Committee


#clean
if($webSite -ne $null) {
    $webSite.Dispose();
}