<#
.SYNOPSIS
    Deletes and recreates the Investigator Document Library .
    
.DESCRIPTION
    Loops through all facility webs and deletes any existing Investigator Document Library and then recreates it.
        
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 120 CreateInvestigatorDocumentLibrary.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\CreateInvestigatorDocumentLibrary.ps1   
#>
Add-PSSnapin Microsoft.SharePoint.Powershell
#Chita please turn versioning on for document library

function GetAllWebs($url){
    try {
        write-log -message "$([String]::Format("Procesing web {0}",$w.Url))" -consoleForeground Cyan
        if($w.Webs.Count -gt 0){
            foreach($web in $w.Webs){
              DeleteInvestigatorDocumentLibrary $web;
              CreateInvestigatorDocumentLibrary $web;
            }
        }
    } catch {
        write-log -message "$([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message))" -consoleForeground Red
        if ($($_.Exception.ErrorRecord)) { write-log -message "$($_.Exception.ErrorRecord)" -consoleForeground Red }
        if ($($_.Exception.stacktrace)) { write-log -message "$($_.Exception.stacktrace)" -consoleForeground Red }
        if ($($_.ScriptStackTrace)) { write-log -message "$($_.ScriptStackTrace)" -consoleForeground Red }
    }
}

function DeleteInvestigatorDocumentLibrary($web) {
  $list = $web.Lists.TryGetList("Investigator Documents")
    if($list -ne $null){
        # The list already exists
        $ListToDeleteName = "Investigator Documents"
 
        #Get Web and List objects
        $list = $web.Lists[$ListToDeleteName]
    
        #Reset the "Allow Deletion" Flag
        $list.AllowDeletion = $true
       
        $list.Update()
        $list.Delete()
        write-log -message "Deleted Investigator Documents $ListToDeleteName Library on $($web.url)" -consoleForeground Yellow
    }
}

function CreateInvestigatorDocumentLibrary($web) {
    $SPTemplate = [Microsoft.Sharepoint.SPListTemplateType]::DocumentLibrary
    $web.Lists.Add("InvestigatorDocuments","InvestigatorDocuments",$SPTemplate)
    
    $list = $web.Lists.TryGetList("InvestigatorDocuments")

    if($list -ne $null){
        $list.Title="Investigator Documents"
        $list.Update()
        write-log -message "Investigator Documents Library $($list.Title) is created on $($web.url)" -consoleForeground Green
    } else {
        write-log -message "Could not create Investigator Documents Library on $($web.url)" -consoleForeground Red
    }
}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://DNS.URL/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
GetAllWebs($siteUrl)