<#

.SYNOPSIS
    Disable-ListAttachments disables attachments on all lists.

.DESCRIPTION
    Iterate through all List Items and check for GenericList, not hidden and enableattachments. Sets the 
    EnableAttachments to false.

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 425 Disable-ListAttachments.ps1

.EXAMPLE
     #when run from the powershell command prompt.
    .\Disable-ListAttachments.ps1

#>


if ((Get-PSSnapin "Microsoft.SharePoint.PowerShell" -ErrorAction SilentlyContinue) -eq $null) {
    Add-PSSnapin "Microsoft.SharePoint.PowerShell"
}
if ($env:COMPUTERNAME -match "VAPH") {
    if (!(Get-Module "RAMS_Module_Util")) {
        if ($Global:diretoryName -eq $null) { 
            $Global:diretoryName = "D:\RAMS-2.3.0\LogFiles"
            $Global:logFileName = "Disable-ListAttachments.log"
        }
        Import-Module .\module\RAMS_Module_Util.psd1 -DisableNameChecking -Global
    } 
} else {
    if (!(Get-Module "RAMS_Module_Util")) {
        if ($Global:diretoryName -eq $null) { 
            $Global:diretoryName = ".\"
            $Global:logFileName = "Disable-ListAttachments.log"
        }
        Import-Module ..\UtilityScripts\RAMS_Module_Util.psd1 -DisableNameChecking -Global
    }
}

$web =get-siteweb

$site = get-spsite $web.url

foreach ($web in $site.Allwebs){
        foreach ($list in $web.lists){
            if($list.basetype -eq "GenericList" -and !($list.hidden) -and ($list.enableattachments)){
                $list.EnableAttachments = $false
                $list.Update()
                Write-log -message "$($list.title),$($list.rootfolder),$($list.parentweburl),$($list.hidden),$($list.basetype),$($list.enableattachments)" -consoleforeground green
            }
             
           }

    }