<#
.SYNOPSIS
    Disable the cter_RAMS_DocumentCTEventReceiver 

.DESCRIPTION
   Finds the cter_RAMS_DocumentCTEventReceiver and disables it. The method used to find the ER is not exact and with 
   this method the status can not be determined, exactly. If it is present Disable-SPFeature is called, followed by 
   a sleep for 60 seconds to make sure it has time to disable across the application. 

.EXAMPLE
     #when run from the powershell command prompt.
    .\EnableEventReciever.ps1
#>
if ((Get-PSSnapin "Microsoft.SharePoint.PowerShell" -ErrorAction SilentlyContinue) -eq $null) {
    Add-PSSnapin "Microsoft.SharePoint.PowerShell"
}
if ($env:COMPUTERNAME -match "VAPH") {
    if (!(Get-Module "RAMS_Module_Util")) {
        if ($Global:diretoryName -eq $null) { 
            $Global:diretoryName = "D:\RAMS-2.3.0\LogFiles"
            $Global:logFileName = "disableEventReceiver.log"
        }
        Import-Module .\module\RAMS_Module_Util.psd1 -DisableNameChecking -Global
    } 
} else {
    if (!(Get-Module "RAMS_Module_Util")) {
        if ($Global:diretoryName -eq $null) { 
            $Global:diretoryName = ".\"
            $Global:logFileName = "disableEventReceiver.log"
        }
        Import-Module ..\UtilityScripts\RAMS_Module_Util.psd1 -DisableNameChecking -Global
    }
}
try {
    $found=$false
    Get-SPFeature -Limit ALL | Where-Object {$_.DisplayName -ilike "*cter_RAMS_DocumentCTEventReceiver*"} | % {
        $ftExists = $_.Id;
        if($ftExists -ne $null){
            Write-log -message "Feature: $($_.DisplayName) is present" -consoleforeground yellow
            disable-SPFeature -Identity $_.Id -Url (get-siteurl) -Verbose -Force -Confirm:$false -ErrorAction Ignore
            start-sleep -Seconds 60
            Write-log -message "Feature: $($_.DisplayName) is Deactivated" -consoleforeground green
            $found=$true
        } else {
            Write-log -message "Feature: $($_.DisplayName) is Not Activated" -consoleforeground green
            $found=$true
        }
    }
    if($found -ne $true){
        Write-log -message "Feature not found" -consoleforeground green
    }
} catch {
    write-host "Unable to get or disable SPFeature." -Foregroundcolor Red
    if ($($_.Exception.ErrorRecord)) { write-log -message "$($_.Exception.ErrorRecord)" -consoleForeground Red }
    if ($($_.Exception.stacktrace)) { write-log -message "$($_.Exception.stacktrace)" -consoleForeground Red }
    if ($($_.ScriptStackTrace)) { write-log -message "$($_.ScriptStackTrace)" -consoleForeground Red }
}