<#
.SYNOPSIS
    Fixes the field order on all calendars
    
.DESCRIPTION
    Loops through each facility subsite and fixes the field order on each IRB, RDC< IACUC< and SRS calendar
      
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 260 FixCalendarOrder.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\FixCalendarOrder.ps1    
#>
Add-PSSnapin Microsoft.SharePoint.Powershell

$facilities = @{
}

function GetAllWebs($url) {
    write-log -message "$([String]::Format("Procesing web {0}",$w.Url))" -consoleForeground Cyan
	if($w.Webs.Count -gt 0) {
	    foreach($web in $w.Webs) {
			FixCalendarOrder $web
	    }
	}
} 
    
function FixCalendarOrder($subweb) {
	#-------------------------------------------------------------------------------------------------------------
    $list = $subweb.Lists.TryGetList("Committee Calendar")
    $contentType = "Event"
    $ct = $list.ContentTypes[$contentType] 

    if($list -ne $null) {
        write-log -message "Fixing Order for Committee Calendar on $($subweb.Url)" -consoleForeground Cyan 
        $contentType = "Event"
        $newFieldOrder = @("Title", 
            "EventDate", 
            "EndDate", 
            "Location", 
            "fAllDayEvent", 
            "fRecurrence",
            "CommitteeAttendees",  
            "ParticipantsPicker",
            "Administrative_x0020_Items", 
            "SubmittedApplicationLookup", 
            "CommitteeMeetingMinuteLookup", 
            "Deliberation",
            "Decision" 
        )
   			
   		if ($list.Fields.ContainsFieldWithStaticName("SubmittedApplicationLookup")) {
	        $ApplicationsStudyLookupField = $list.Fields.TryGetFieldByStaticName("SubmittedApplicationLookup");
	        $ApplicationsStudyLookupField.ShowInEditForm=$True;
	        $ApplicationsStudyLookupField.ShowInNewForm=$True;
	        $ApplicationsStudyLookupField.Update($true)
	        $list.Update($true)
	    }
      	if ($list.Fields.ContainsFieldWithStaticName("CommitteeMeetingMinuteLookup")) {
	        $ApplicationsStudyLookupField = $list.Fields.TryGetFieldByStaticName("CommitteeMeetingMinuteLookup");
	        $ApplicationsStudyLookupField.ShowInEditForm=$True;
	        $ApplicationsStudyLookupField.ShowInNewForm=$True;
	        $ApplicationsStudyLookupField.Update($true)
	        $list.Update($true)
	    }        	
      	if ($list.Fields.ContainsFieldWithStaticName("Decision")) {
	        $ApplicationsStudyLookupField = $list.Fields.TryGetFieldByStaticName("Decision");
	        $ApplicationsStudyLookupField.ShowInEditForm=$True;
	        $ApplicationsStudyLookupField.ShowInNewForm=$True;
	        $ApplicationsStudyLookupField.Update($true)
	        $list.Update($true)
	    }        	
      	if ($list.Fields.ContainsFieldWithStaticName("Deliberation")) {
	        $ApplicationsStudyLookupField = $list.Fields.TryGetFieldByStaticName("Deliberation");
	        $ApplicationsStudyLookupField.ShowInEditForm=$True;
	        $ApplicationsStudyLookupField.ShowInNewForm=$True;
	        $ApplicationsStudyLookupField.Update($true)
	        $list.Update($true)
	    }        	
      	if ($list.Fields.ContainsFieldWithStaticName("TaxKeyword")) {
	        $ApplicationsStudyLookupField = $list.Fields.TryGetFieldByStaticName("TaxKeyword");
	        $ApplicationsStudyLookupField.ShowInEditForm=$False;
	        $ApplicationsStudyLookupField.ShowInNewForm=$False;
            $ApplicationsStudyLookupField.Hidden = $True;
	        $ApplicationsStudyLookupField.Update($true)
	        $list.Update($true)
	    }
        $ct = $list.ContentTypes[$contentType]
        $ct.FieldLinks.Reorder($newFieldOrder)
        $ct.Update() 
        $list.Update()
        $subweb.Update()
    }	
        
	#-------------------------------------------------------------------------------------------------------------
    $list = $subweb.Lists.TryGetList("RDC Calendar")
    if($list -ne $null) {
        write-log -message "Fixing Order for RDC Calendar on $($subweb.Url)" -consoleForeground Cyan
        $contentType = "Event"
        $newFieldOrder = @("Title", 
        "EventDate", 
        "EndDate", 
        "Location", 
        "fAllDayEvent", 
        "fRecurrence",
        "CommitteeAttendees",  
        "EventAttendees",
        "Administrative_x0020_Items",  
        "ApprovedApplicationsLookup", 
        "RDCMeetingMinuteLookup", 
        "Deliberation",
        "Decision"
        )

        if ($list.Fields.ContainsField("TaxKeyword")) {
            $enterpriseField = $list.Fields.GetFieldByInternalName("TaxKeyword")
            $list.Fields.Delete($enterpriseField)   
            #$enterpriseField.Update($true)
            $list.Update($true)
        }
 
        if ($list.Fields.ContainsField("Category")) {
	        $categoryfield=$list.Fields["Category"]
	        $categoryfield.ShowInNewForm=$false 
	        $categoryfield.ShowInEditForm=$false
	        $categoryfield.Update($true)
	        $list.Update($true)
       	}

        if ($list.Fields.ContainsField("EventAdministrativeItems")) {
	        $EventAdministrativeItemsField = $list.Fields.GetFieldByInternalName("EventAdministrativeItems");
	        $EventAdministrativeItemsField.ShowInEditForm=$false;
	        $EventAdministrativeItemsField.ShowInNewForm=$false;
	        $EventAdministrativeItemsField.Update($true)
	        $list.Update($true)
        }

        if ($list.Fields.ContainsField("EventAttendees")) {
	        $EventAttendeesField = $list.Fields.GetFieldByInternalName("EventAttendees");
	        $EventAttendeesField.ShowInEditForm=$true;
	        $EventAttendeesField.ShowInNewForm=$true;
	        $EventAttendeesField.Update($true)
	        $list.Update($true)
		}
		
		if ($list.Fields.ContainsField("Attendees")) {
	        $EventAttendeesField = $list.Fields.GetFieldByInternalName("EventAttendees");
	        $EventAttendeesField.ShowInEditForm=$true;
	        $EventAttendeesField.ShowInNewForm=$true;
	        $EventAttendeesField.Update($true)
	        $list.Update($true)
		}
             
        if ($list.Fields.ContainsField("EventCommitteeAttendees")) {
	        $CommitteeAttendeesField  = $list.Fields.GetFieldByInternalName("EventCommitteeAttendees");
	        $CommitteeAttendeesField.ShowInEditForm=$false;
	        $CommitteeAttendeesField.ShowInNewForm=$false;
	        $CommitteeAttendeesField.Update($true)
	        $list.Update($true)
        }

        if ($list.Fields.ContainsField("EventCommitteeAttendees")) {
	        $DecisionField  = $list.Fields.GetFieldByInternalName("EventCommitteeAttendees");
	        $DecisionField.ShowInEditForm=$false;
	        $DecisionField.ShowInNewForm=$false;
	        $DecisionField.Update($true)
	        $list.Update($true)
        }

        if ($list.Fields.ContainsField("ApplicationsLookup")) {
      	    $applicationsField=$list.Fields["ApplicationsLookup"]
            $applicationsField.ShowInNewForm=$false 
            $applicationsField.ShowInEditForm=$false
            $applicationsField.Update($true)
            $list.Update($true)
      	}
      	  
      	if ($list.Fields.ContainsField("ApprovedRDCApplicationLookup")) {
      	    $approvedRDCApplicationLookup=$list.Fields["ApprovedRDCApplicationLookup"]
            $approvedRDCApplicationLookup.ShowInNewForm=$false 
            $approvedRDCApplicationLookup.ShowInEditForm=$false
            $approvedRDCApplicationLookup.Update($true)
            $list.Update($true)
      	}

	    $ct = $list.ContentTypes[$contentType] 
        if ($list.Fields.ContainsField("Description")) {
	        #$ct = $list.ContentTypes[$contentType] 
	        $ct.FieldLinks["Description"].Hidden = $True
	        #$ct.Update() 
	        #$list.Update($true)
            #$subweb.Update()
        }

	    #$ct = $list.ContentTypes[$contentType] 
        $ct.FieldLinks.Reorder($newFieldOrder)
        $ct.Update() 
        $list.Update()
        $subweb.Update()
    }
          
	#-------------------------------------------------------------------------------------------------------------
    $list = $subweb.Lists.TryGetList("IACUC Calendar")
    if($list -ne $null) {
        write-log -message "Fixing Order for IACUC Calendar on $($subweb.Url)" -consoleForeground Cyan 
        $contentType = "Event"
        $newFieldOrder = @("Title", 
            "EventDate", 
            "EndDate", 
            "Location", 
            "fAllDayEvent", 
            "fRecurrence",
            "CommitteeAttendees",  
            "EventAttendees",
            "Administrative_x0020_Items", 
            "SubmittedApplicationLookup", 
            "IACUCMeetingMinuteLookup", 
            "Deliberation",
            "Decision"
        )
              
        if ($list.Fields.ContainsField("TaxKeyword")) {
            $enterpriseField = $list.Fields.GetFieldByInternalName("TaxKeyword")
            $list.Fields.Delete($enterpriseField)   
        }

        if ($list.Fields.ContainsField("Category")) {
	        $categoryfield=$list.Fields["Category"]
	        $categoryfield.ShowInNewForm=$false 
	        $categoryfield.ShowInEditForm=$false
	        $categoryfield.Update($true)
	        $list.Update()
       	}
       
      	if ($list.Fields.ContainsField("ApplicationsLookup")) {
      	    $applicationsField=$list.Fields["ApplicationsLookup"]
            $applicationsField.ShowInNewForm=$false 
            $applicationsField.ShowInEditForm=$false
            $applicationsField.Update($true)
            $list.Update()
      	}
      	  
      	if ($list.Fields.ContainsField("ApprovedRDCApplicationLookup")) {
      	    $approvedRDCApplicationLookup=$list.Fields["ApprovedRDCApplicationLookup"]
            $approvedRDCApplicationLookup.ShowInNewForm=$false 
            $approvedRDCApplicationLookup.ShowInEditForm=$false
            $approvedRDCApplicationLookup.Update($true)
            $list.Update()
      	}

	    $ct = $list.ContentTypes[$contentType] 
        if ($list.Fields.ContainsField("Description")) {
	        #$ct = $list.ContentTypes[$contentType] 
	        $ct.FieldLinks["Description"].Hidden = $True
	        #$ct.FieldLinks.Reorder($newFieldOrder)
	        #$ct.Update() 
	        #$list.Update()
        }

	    #$ct = $list.ContentTypes[$contentType] 
        $ct.FieldLinks.Reorder($newFieldOrder)
        $ct.Update() 
        $list.Update()
        $subweb.Update()
    }	

	#-------------------------------------------------------------------------------------------------------------
    $list = $subweb.Lists.TryGetList("SRS Calendar")
    if($list -ne $null) {
        write-log -message "Fixing Order for SRS Calendar on $($subweb.Url)" -consoleForeground Cyan
        $contentType = "Event"
        $newFieldOrder = @("Title", 
            "EventDate", 
            "EndDate", 
            "Location", 
            "fAllDayEvent", 
            "fRecurrence",
            "EventCommitteeAttendees",  
            "EventAttendees",
            "EventAdministrativeItems", 
            "SubmittedApplicationLookup", 
            "SRSMeetingMinuteLookup", 
            "Deliberation",
            "Decision"
        )
             
        if ($list.Fields.ContainsField("TaxKeyword")) {
            $enterpriseField = $list.Fields.GetFieldByInternalName("TaxKeyword")
            $list.Fields.Delete($enterpriseField)   
        }
           
        if ($list.Fields.ContainsField("Category")) {
	        $categoryfield=$list.Fields["Category"]
	        $categoryfield.ShowInNewForm=$false 
	        $categoryfield.ShowInEditForm=$false
	        $categoryfield.Update($true)
	        $list.Update()
       	}
       
      	if ($list.Fields.ContainsField("ApplicationsLookup")) {
      	    $applicationsField=$list.Fields["ApplicationsLookup"]
            $applicationsField.ShowInNewForm=$false 
            $applicationsField.ShowInEditForm=$false
            $applicationsField.Update($true)
            $list.Update()
      	}
      	  
      	if ($list.Fields.ContainsField("ApprovedRDCApplicationLookup")) {
      	    $approvedRDCApplicationLookup=$list.Fields["ApprovedRDCApplicationLookup"]
            $approvedRDCApplicationLookup.ShowInNewForm=$false 
            $approvedRDCApplicationLookup.ShowInEditForm=$false
            $approvedRDCApplicationLookup.Update($true)
            $list.Update()
      	}

        $ct = $list.ContentTypes[$contentType] 
        if ($list.Fields.ContainsField("Description")) {
	        #$ct = $list.ContentTypes[$contentType] 
	        $ct.FieldLinks["Description"].Hidden = $True
	        #$ct.Update() 
	        #$list.Update()
        }

        #$ct = $list.ContentTypes[$contentType] 
        $ct.FieldLinks.Reorder($newFieldOrder)
        $ct.Update() 
        $list.Update()
        $subweb.Update()
    }	
}
	
#This is to test the driver contains a $siteUrl
#$siteUrl="https://DNS.URL/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
GetAllWebs($siteUrl)
