<#

.SYNOPSIS
    Gets a list of SPUserSolutions or a specific SPUserSolution in a web application.

.DESCRIPTION
    Loops through each site in a web application and retrieves the SPUserSolutions. Builds an ArrayList with 
    SolutionName, SolutionId, SolutionStatus, and SiteCollectionUrl.
    At the end, prints the ArrayList with SPUserSolution information.

.PARAMETER SolutionName
    [String] The name of the solution file.

.PARAMETER WebApplicationUrl
    [String] The URL for the Web Application.
    
.NOTES
    modified based on script from https://blog.ithinksharepoint.com/2015/11/30/powershell-getting-sandbox-solutions-in-a-sharepoint-web-application/

.EXAMPLE
    .\Get-SPUserSolutionInWebApplication -SolutionName "Solution Name" -WebApplicationUrl "https://DNS.URL/sites/IRBApplications" 

#>
param (
   [Parameter(Mandatory=$false, HelpMessage='Solution Name')]
   [string]$SolutionName="",
   [Parameter(Mandatory=$false, HelpMessage='Solution Name')]
   [string]$WebApplicationUrl=""
)
# modified based on script from https://blog.ithinksharepoint.com/2015/11/30/powershell-getting-sandbox-solutions-in-a-sharepoint-web-application/
$memoryAssignment = Start-SPAssignment;
$solutions = New-Object System.Collections.ArrayList
$numberOfSolutionsFound = 0;
#$webApplication = Get-SPWebApplication -Identity $WebApplicationUrl -ErrorAction SilentlyContinue -AssignmentCollection $memoryAssignment;
$webApplication = Get-SPWebApplication -Identity $WebApplicationUrl -AssignmentCollection $memoryAssignment;
if($webApplication -ne $null) {
   #enumerate through site collections in web application
   $allSites = Get-SPSite -WebApplication $webApplication -Limit ALL -Confirm:$false -AssignmentCollection $memoryAssignment;
   foreach($checkSite in $allSites) {
      #Write-Output "Checking Site " $checkSite.Url " for solution " $SolutionName;
      if($SolutionName -eq "") {
         $checkSolutions = Get-SPUserSolution -Site $checkSite -AssignmentCollection $memoryAssignment;
         foreach($solution in $checkSolutions) {
            $output = New-Object -TypeName "System.Object";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SolutionName" -Value "";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SolutionId" -Value "";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SolutionStatus" -Value "";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SiteCollectionUrl" -Value "";
            $output.SolutionName = $solution.Name;
            $output.SolutionId = $solution.SolutionId;
            $output.SolutionStatus = $solution.Status;
            $output.SiteCollectionUrl = $checkSite.Url;
            $solutions.Add($output) | Out-Null
            #Write-Output -InputObject $output;
            #Write-Host "$($solution.Name)`t$($checkSite.Url)" -ForegroundColor White;
            $numberOfSolutionsFound++
         }
      } else {
         $checkSolution = Get-SPUserSolution -Identity $SolutionName -Site $checkSite -ErrorAction SilentlyContinue -AssignmentCollection $memoryAssignment;
         if($checkSolution -ne $null) {
            $output = New-Object -TypeName "System.Object";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SolutionName" -Value "";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SolutionId" -Value "";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SolutionStatus" -Value "";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "SiteCollectionUrl" -Value "";
            $output.SolutionName = $checkSolution.Name;
            $output.SolutionId = $checkSolution.SolutionId;
            $output.SolutionStatus = $checkSolution.Status;
            $output.SiteCollectionUrl = $checkSite.Url;
            $solutions.Add($output) | Out-Null
            #Write-Output -InputObject $output;
            #Write-Host "$($checkSolution.Name)`t$($checkSite.Url)" -ForegroundColor White;
            $numberOfSolutionsFound++
         }
      }
   }
}
#$solutions | %{Write-Host $_.Solution.Name in $_.SiteCollection.Url}
$solutions | Sort SolutionName | format-table -property SolutionName, SolutionId, SolutionStatus, SiteCollectionUrl -AutoSize
Write-Output "Found $numberOfSolutionsFound Instances of Solution $SolutionName";
Stop-SPAssignment $memoryAssignment;
