<#

.SYNOPSIS
    Updates the SharePoint MasterPage and applies it to the site

.DESCRIPTION
    Assumes the name of the MasterPage and its location in the deployment package path. Updates the master page in the 
    _catalog and then applies the master page to the site collection and all facility subsites.

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 410 MasterPageSetter.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\MasterPageSetter.ps1
#>


$MasterPage = "irb-applications.html"
$SourcePath = "D:\$RAMSVersion\_catalogs\masterpage\RAMS MasterpageTemplate\irb-applications.html"

#Get the Web
$web = Get-SPWeb (Get-SiteURL)
 
#Get the Target folder - Master page Gallery
$MasterPageList = $web.GetFolder("Master Page Gallery")
 
#Set the Target file for Master page
$TargetPath = $Web.Url + "/_catalogs/masterpage/irb-applications.html"
 
#Get the Master page from local disk
$MasterPageFile = (Get-ChildItem $SourcePath).OpenRead()

#Check if file exist already
if ($Web.GetFile($TargetPath).Exists) {
    $Web.GetFile($TargetPath).recycle() 
}

#upload master page using powershell
$MasterPage = $MasterPageList.Files.Add($TargetPath,$MasterPageFile,$True) | write-log -consoleForeground Gray
$web.Update()

  
$site = Get-SPWeb (Get-SiteURL)
$masterurl = "/_catalogs/masterpage/RAMS MasterPageTemplate/irb-applications.master"
$rootWeb = $site | Where-Object {$_.isRootWeb -eq $True}
foreach ($web in $site.Webs) {
    $web.MasterUrl = $rootWeb.ServerRelativeUrl +  $masterurl;
    $web.CustomMasterUrl = $rootWeb.ServerRelativeUrl + $masterurl;
    $web.Update();
    write-log -message "Master page applied on: $web AS ==> $($web.MasterUrl) $($web.CustomMasterUrl)" -consoleForeground Green
}
$site.Dispose()

<#
$site = Get-SPWeb (Get-SiteURL)  
$rootWeb = $site | Where-Object {$_.isRootWeb -eq $True}
foreach ($web in $site.Webs)
{
    $web.MasterUrl =  "/_catalogs/masterpage/RAMS MasterPageTemplate/irb-applications.html";
    $web.CustomMasterUrl = "/_catalogs/masterpage/RAMS MasterPageTemplate/irb-applications.html";
    $web.Update();
    write-log -message "Master page applied on: $web AS ==> $($web.MasterUrl) $($web.CustomMasterUrl)" -consoleForeground Green
}
$site.Dispose()
#>















