<#
.SYNOPSIS
    Adds the Facilities Lookup to the Committee Roster List and migrates the data.

.DESCRIPTION
    Adds the FacilitiesLookup to the Committee Roster CT
    For each record in the CommitteeRoster, migrate the Old Facility Lookup to the new Facilities Lookup
    Update the Forms to show the new Facilities Lookup

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 310 MigrateCommitteeRoster.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\MigrateCommitteeRoster.ps1    

#>

Add-PSSnapin Microsoft.SharePoint.Powershell

function GetRosterItems($url)
{
    try
    {
        write-log -message "$([String]::Format("Procesing web {0}",$w.Url))" -consoleForeground Cyan
        $rosterlist =$w.Lists["CommitteeRoster"]
        $rosteritems = $rosterlist.items
		#CREATE SITE COLUMNS
		write-log -message "ADDING SITE COLUMNS TO CONTENT TYPE" -consoleForeground Green
        Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Committee Roster CT" -sFieldInternalName "FacilitiesLookup" -sFieldStaticName "FacilitiesLookup"

        #Loop through List
        #Get Facility Lookup
        #Copy record to correct field
	  	foreach ($item in $rosteritems) {
	  	   $rosterItemID=$item["ID"]
            $rosterFacilityLookup=$item["Facility"]
            
	       if($w.Webs.Count -gt 0 -and $rosterFacilityLookup)
	        {
	         
	          $facilityTitle = $rosterFacilityLookup.substring(4);
              $facilitiesItem = GetFacilitiesItem($facilityTitle)
	          $item["Facilities Lookup"] = $facilitiesItem.ID
              $item.Update()
	      
	        }
	    }
        $facilityField=$rosterlist.Fields["Facility"]
        $facilityField.Delete()
        FixForms $rosterlist
        $rosterlist.Update()
        		 	 
    }

    catch
    {
        write-log -message "$([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message))" -consoleForeground Red
        if ($($_.Exception.ErrorRecord)) { write-log -message "$($_.Exception.ErrorRecord)" -consoleForeground Red }
        if ($($_.Exception.stacktrace)) { write-log -message "$($_.Exception.stacktrace)" -consoleForeground Red }
        if ($($_.ScriptStackTrace)) { write-log -message "$($_.ScriptStackTrace)" -consoleForeground Red }
    }   

   
 } 
 
 function FixForms ($list) {

	$ct = $list.ContentTypes["Committee Roster CT"] 

    $fldList = @(
	 "MemberName",
	 "MembershipType",
	 "MembershipStatus",
	 "FacilitiesLookup",
	 "CommitteeMembership",
	 "ServiceSpecialty",
	 "Position",
	 "EmploymentStatus",
	 "TermExpiration"
	
	
)
	$ct.FieldLinks.Reorder($fldList)
    $ct.Update()
    $list.Update()

 }


    function GetFacilitiesItem ($title) {
	    $rosterList = (Get-SiteWeb).Lists.TryGetList("Facilities")
	    $spListItem =  $rosterList.Items | ? {$_["Title"] -match $title}
	    return $spListItem;
    }
    
#This is to test the driver contains a $siteUrl
#$siteUrl="https://DNS.URL/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
GetRosterItems($siteUrl)