<#

.SYNOPSIS
    Builds a new Data Sharing Repository Agreements (DSRA) List and migrates the data from the old list.

.DESCRIPTION
    Creates Facilities Lookup for the DSRA list
    Adds the site columns to the DSRA Content Type
    Renames the DSRA list to OldDataSharingRepositoryAgreements
    Creates a new DSRA list 
    NOT USED - Migrates the data from the old DSRA to the new DSRA - This kept getting errors in development so, since the data in production is only test data, this step is commented out.
    Created the DSRA Standard View
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 340 MigrateDataSharingRepository.ps1

.EXAMPLE
    #when run from command line
    .\MigrateDataSharingRepository.ps1
#>
Add-PSSnapin Microsoft.SharePoint.Powershell

function CreateDataSharingRepositoryFacilityLookups () {
    try {  
        #CREATE SITE COLUMNS
        write-log -message "CREATING SITE COLUMNS for 'Site Shared With'" -consoleForeground Gray
        
        # GET THE LISTS
        $myList = $w.Lists["Facilities"];
    
        #Where the Source List for Lookup Exists
        
        $ParentWebURL=$siteURL
        $ParentListName="Facilities"
        $ParentLookupColumnName="Title"
        
        #Where the Lookup Site column Going to get created
        $ChildWebURL=$siteURL
        $ChildLookupColumnName="SiteSharedWith"
        
        #Get the Parent and Child Webs and List
        
        $ParentWeb = $w
        $ParentList = $w.Lists[$ParentListName]
        $ChildWeb = $w
        
        if(!$ChildWeb.Fields.ContainsField($ChildLookupColumnName)) {
            #Add Lookup Field
            $ChildLookupColumn = $ChildWeb.Fields.AddLookup($ChildLookupColumnName,$ParentList.id,$False)
            $ChildLookupColumn = $ChildWeb.Fields[$ChildLookupColumnName]
            
            #Setup lookup Field property
            $ChildLookupColumn.LookupWebId = $ParentWeb.ID
            $ChildLookupColumn.LookupField = $ParentList.Fields[$ParentLookupColumnName].InternalName
            
            #$ChildLookupColumn.AllowMultipleValues=$true
            $ChildLookupColumn.Group="RAMS IRB" 
            $ChildLookupColumn.Title="Site Shared With"
           
            $ChildLookupColumn.update()
            write-log -message "Lookup field $($ChildLookupColumn.InternalName) added successfully!" -consoleForeground green
        } else {
            write-log -message "Field $ChildLookupColumnName exists already!" -consoleForeground red
        }
    } catch {
        write-log -message "Exception Occurred:" -consoleForeground Red
        write-log -message "$($_.Exception.Message)" -consoleForeground Red
        if ($($_.Exception.ErrorRecord)) { write-log -message "$($_.Exception.ErrorRecord)" -consoleForeground Red }
        if ($($_.Exception.stacktrace)) { write-log -message "$($_.Exception.stacktrace)" -consoleForeground Red }
        if ($($_.ScriptStackTrace)) { write-log -message "$($_.ScriptStackTrace)" -consoleForeground Red }
    } 
}

function CreatDSRAContentType($subweb) {
    $dsraCT = New-Object Microsoft.SharePoint.SPContentType($w.AvailableContentTypes["Item"],$w.ContentTypes,"DSRA CT")
    $dsraCT.Group = "RAMS IRB"
    $w.ContentTypes.Add($dsraCT) | write-log -consoleForeground White
    $w.Update()
}

function AddSiteColumnsToContentType() {
    write-log -message "AddSiteColumnsToContentType DSRA CT" -consoleForeground Cyan
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "DSRA CT" -sFieldInternalName "DSTypeOfAgreement" -sFieldStaticName "DSTypeOfAgreement"
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "DSRA CT" -sFieldInternalName "SiteSharedWith" -sFieldStaticName "SiteSharedWith"
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "DSRA CT" -sFieldInternalName "StudyTitle" -sFieldStaticName "StudyTitle"
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "DSRA CT" -sFieldInternalName "DSIRBApproval" -sFieldStaticName "DSIRBApproval"
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "DSRA CT" -sFieldInternalName "StartDate" -sFieldStaticName "StartDate"
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "DSRA CT" -sFieldInternalName "RenewalDate" -sFieldStaticName "RenewalDate"
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "DSRA CT" -sFieldInternalName "DSPIName" -sFieldStaticName "DSPIName"   
}

function AdjustContentType () {
    #ADJUST CONTENT TYPE ON LIST
    write-log -message "ADJUST CONTENT TYPE 'DSRA'" -consoleForeground Cyan
    $ct = $w.ContentTypes["DSRA CT"] 
    $fldList = @(
        "Title",
        "DSTypeOfAgreement",
        "SiteSharedWith",
        'StudyTitle',
        "DSIRBApproval",
        "StartDate",
        "RenewalDate",
        "DSPIName"
    )
    $ct.FieldLinks.Reorder($fldList)
    $ct.Update($true)
}

function RecreateList ($subweb) {
    #rename current facility list to old list
    $agreementslist =$subweb.Lists["DataSharingRepositoryAgreements"]
    $agreementslist.Title = "Old DataSharingRepositoryAgreements"
    $oldagreementslist = $subweb.Lists.TryGetList("OldDataSharingRepositoryAgreements")
    if($oldagreementslist){
        $oldagreementslist.AllowDeletion = $true
        $oldagreementslist.Update()
        $oldagreementslist.Delete()
        write-log -message "Removed an OldDataSharingRepositoryAgreements List" -consoleForeground Yellow
    }
    $agreementslist.RootFolder.MoveTo("OldDataSharingRepositoryAgreements")
    #$agreementslist.Update()
    write-log -message "Renamed the DataSharingRepositoryAgreements list to OldDataSharingRepositoryAgreements" -consoleForeground Yellow
    
    #create new facility list
    $listTemplate = $w.ListTemplates | ? {$_.InternalName -match "custlist"}
    $subweb.Lists.Add("DataSharingRepositoryAgreements","DataSharingRepositoryAgreements", $listTemplate)
    write-log -message "Created New DataSharingRepositoryAgreements List on $($subweb.URL)" -consoleForeground Gray
}

function AddContentTypeToList($subweb) {
    $agreementslist = $subweb.Lists["DataSharingRepositoryAgreements"]
    $dsraCT = $w.ContentTypes["DSRA CT"]
    
    $ctOnList=$agreementslist.ContentTypes["DSRA CT"]
    if($ctOnList -eq $null) {
        $agreementslist.ContentTypes.Add($dsraCT) | write-log -consoleForeground white
        $agreementslist.ContentTypes["Item"].Delete()
        #$agreementslist.ContentTypes["Folder"].Delete()
        $agreementslist.Update()
    }
}

function MigrateDataSharingRepositoryItems($subweb) {
    try {
        write-log -message "$([String]::Format("Procesing web {0}",$subweb.Url))" -consoleForeground White
        write-log -message "MOVING DataSharingRepositoryAgreements OLD FIELDS TO DataSharingRepositoryAgreements LIST" -consoleForeground Green
        #Read needed items from the old facilit
        $oldAgreementsList = $subweb.Lists.TryGetList("OldDataSharingRepositoryAgreements")
        $agreementsList =$subweb.Lists["DataSharingRepositoryAgreements"]
        
        write-log -message "Migrating $($oldAgreementsList.ItemCount) $($agreementsList.Title) records" -consoleForeground White
        
        foreach($oldItem in $oldAgreementsList.Items) {
            Write-log -message "Migrating old record: $oldItem" -consoleForeground Gray
            $newItem = $agreementsList.AddItem()  
            
            if ($oldItem["Title"] -ne $null) {
                $newItem["Title"] = $oldItem["Title"]
            }
            
            if ($oldItem["Type Of Agreement"] -ne $null) {
                $newItem["Type Of Agreement"] = $oldItem["Type Of Agreement"]
            }
            
            $agreementsFacilitySharedLookup = $oldItem["Facility Shared With"]
            
            if ($agreementsFacilitySharedLookup -ne $null) {
                $agreementsFacilitySharedLookupIndex = $agreementsFacilitySharedLookup.IndexOf("#") + 1
                $agreementsFacilitySharedLookupTitle = $agreementsFacilitySharedLookup.substring($agreementsFacilitySharedLookupIndex)
                $agreementsFacilitySharedLookupItem =GetFacilitiesItem($agreementsFacilitySharedLookupTitle)
            }
            
            if ($oldItem["Study Title"] -ne $null) {
                $newItem["Site Shared With"] = $agreementsFacilitySharedLookupItem.Id
            }
           
            if ($oldItem["Study Title"] -ne $null) {
                $newItem["Study Title"] = $oldItem["Study Title"]
            }
            
            if ($oldItem["IRB Approval"] -ne $null) {
                $newItem["IRB Approval"] = $oldItem["IRB Approval"]
            }
            
            if ($oldItem["Start Date"] -ne $null) {
                $newItem["Start Date"] = $oldItem["Start Date"]
            }
            
            if ($oldItem["Renewal Date"] -ne $null) {
                $newItem["Renewal Date"] = $oldItem["Renewal Date"]
            }
            
            if ($oldItem["PI Name"] -ne $null) {
                $newItem["PI Name"] = $oldItem["PI Name"]
            }
            
            $newItem.Update()
            write-log -message "New item has been added to DaraSharingRepositoryAgreements." -consoleForeground Green
        }
    } catch {
        write-log -message "$([String]::Format("Error processing web at {0}, with Exception: {1}", $subweb.Url, $_.Exception.Message))" -consoleForeground Red
    }
}

function GetFacilitiesItem ($title) {
    $facilitiesList = (Get-SiteWeb).Lists.TryGetList("Facilities")
    $spListItem =  $facilitiesList.Items | ? {$_["Title"] -match $title}
    return $spListItem;
}
    
function ModifyAllItemsView ($subweb) {
    $list = $subweb.Lists.TryGetList("DataSharingRepositoryAgreements")
    $fldList = @(
        'LinkTitle'; 
        'DSTypeOfAgreement';
        'SiteSharedWith';
        'StudyTitle'; 
        'DSIRBApproval'; 
        'StartDate'; 
        'RenewalDate'; 
        'DSPIName'
    )
    $viewQuery = "<Where></Where>"
    New-SpFacilityListView -web $subweb -fldList $fldList -viewTitle 'AgreementsView' -listName $list.Title -viewQuery $viewQuery -viewRowLimit '50'
    $view=$list.Views["AgreementsView"]
    $view.DefaultView = $true
    $view.MobileView = $true
    $view.MobileDefaultView = $true
    $view.Update()
}

function DeleteAllItemsView ($list) {
    $view=$list.Views["All Items"]
    if ($view -ne $null) {
        $list.Views.Delete($view.Id)
        $list.Update()
    }
}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://DNS.URL/sites/IRBApplications/";
$w = Get-SiteWeb
write-log -message "Updating and Migrating Data Sharing Repository Agreements" -consoleForeground Magenta
CreateDataSharingRepositoryFacilityLookups
CreatDSRAContentType
AddSiteColumnsToContentType
AdjustContentType
$siteUrl = Get-SiteURL

(Get-SiteWeb).Webs | % {
    $facilitySite = $_
    #Recreate DataSharingRepositoryAgreements
    RecreateList $facilitySite
    AddContentTypeToList $facilitySite
    
    #MigrateDataSharingRepositoryItems  $facilitySite
    ModifyAllItemsView $facilitySite
}
