<#

.SYNOPSIS
    Builds a new FWAMOU List and migrates the data from the old list.

.DESCRIPTION
    Creates Facilities Lookup for the FWAMOU list
    Adds the site columns to the FWAMOU Content Type
    Renames the FWAMOU list to Old FWAMOU
    Creates a new FWAMOU list 
    NOT USED - Migrates the data from the old FWAMOU to the new FWAMOU - This kept getting errors in development so, since the data in production is only test data, this step is commented out.
    Created the FWAMOU Standard View
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 330 MigrateFWAMOU.ps1

.EXAMPLE
    #when run from command line
    .\MigrateFWAMOU.ps1
#>
Add-PSSnapin Microsoft.SharePoint.Powershell

function CreateFWAFacilityLookups () {
    try {  
        #CREATE SITE COLUMNS
        write-log -message "CREATING SITE COLUMNS for FWAMOU" -consoleForeground Gray
        
        # GET THE LISTS
        $myList = $w.Lists["Facilities"];
        
        #Where the Source List for Lookup Exists
        $ParentWebURL=$siteURL
        $ParentListName="Facilities"
        $ParentLookupColumnName="Title"
        
        #Where the Lookup Site column Going to get created
        $ChildWebURL=$siteURL
        $ChildLookupColumnName="SourceSiteName"
        
        #Get the Parent and Child Webs and List
        
        $ParentWeb = $w
        $ParentList = $w.Lists[$ParentListName]
        $ChildWeb = $w
        
        if(!$ChildWeb.Fields.ContainsField($ChildLookupColumnName)) {
            #Add Lookup Field
            $ChildLookupColumn = $ChildWeb.Fields.AddLookup($ChildLookupColumnName,$ParentList.id,$False)
            $ChildLookupColumn = $ChildWeb.Fields[$ChildLookupColumnName]
        
            #Setup lookup Field property
            $ChildLookupColumn.LookupWebId = $ParentWeb.ID
            $ChildLookupColumn.LookupField = $ParentList.Fields[$ParentLookupColumnName].InternalName
        
            #$ChildLookupColumn.AllowMultipleValues=$true
            $ChildLookupColumn.Group="RAMS IRB" 
            $ChildLookupColumn.Title="Source Site Name"
            
            $ChildLookupColumn.update()
            write-log -message "Lookup field $($ChildLookupColumn.InternalName) added successfully!" -consoleForeground green
        } else {
            write-log -message "Field $($ChildLookupColumn.InternalName) exists already!" -consoleForeground red
        }  
        
        $ChildLookupColumnName="PartnerSiteName"
        
        #Get the Parent and Child Webs and List
        $ParentWeb = $w
        $ParentList = $w.Lists[$ParentListName]
        $ChildWeb = $w
        
        if(!$ChildWeb.Fields.ContainsField($ChildLookupColumnName)) {
            #Add Lookup Field
            $ChildLookupColumn = $ChildWeb.Fields.AddLookup($ChildLookupColumnName,$ParentList.id,$False)
            $ChildLookupColumn = $ChildWeb.Fields[$ChildLookupColumnName]
            
            #Setup lookup Field property
            $ChildLookupColumn.LookupWebId = $ParentWeb.ID
            $ChildLookupColumn.LookupField = $ParentList.Fields[$ParentLookupColumnName].InternalName
            
            #$ChildLookupColumn.AllowMultipleValues=$true
            
            $ChildLookupColumn.Group="RAMS IRB" 
            $ChildLookupColumn.Title="Partner Site Name"
            
            $ChildLookupColumn.update()
            write-log -message "Lookup field $($ChildLookupColumn.InternalName) added successfully!" -consoleForeground green
        } else {
            write-log -message "Field $ChildLookupColumnName exists already!" -consoleForeground red
        }  
    } catch {
        write-log -message "Exception Occurred:" -consoleForeground Red
        write-log -message "$($_.Exception.Message)" -consoleForeground Red
        if ($($_.Exception.ErrorRecord)) { write-log -message "$($_.Exception.ErrorRecord)" -consoleForeground Red }
        if ($($_.Exception.stacktrace)) { write-log -message "$($_.Exception.stacktrace)" -consoleForeground Red }
        if ($($_.Exception.ScriptStackTrace)) { write-log -message "$($_.Exception.ScriptStackTrace)" -consoleForeground Red }
    } 
}

function AddSiteColumnsToContentType() {
    write-log -message "AddSiteColumnsToContentType FWAMOU CT" -consoleForeground Cyan
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "FWAMOU CT" -sFieldInternalName "SourceSiteName" -sFieldStaticName "SourceSiteName"
    Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "FWAMOU CT" -sFieldInternalName "PartnerSiteName" -sFieldStaticName "PartnerSiteName"
}

function RecreateList () {
    #rename current facility list to old list
    $fwamoulist =$w.Lists["FWAMOU"]
    $fwamoulist.Title = "Old FWAMOU"
    $oldfwamoulist = $w.Lists.TryGetList("OldFWAMOU")
    if($oldfwamoulist){
        $oldfwamoulist.AllowDeletion = $true
        $oldfwamoulist.Update()
        $oldfwamoulist.Delete()
        write-log -message "Removed an $($oldfwamoulist.Title) List" -consoleForeground Yellow
    }
    $fwamoulist.RootFolder.MoveTo("OldFWAMOU")
    #$fwamoulist.Update()
    write-log -message "Renamed the FWAMOU list to OLDFWAMOU" -consoleForeground Yellow
    
    #create new Custom List (custlist)
    $listTemplate = $w.ListTemplates | ? {$_.InternalName -match "custlist"}
    $w.Lists.Add("FWAMOU","FWAMOU", $listTemplate)
    write-log -message "Created New FWAMOU List on $($w.URL)" -consoleForeground Gray
    
    $ct = $w.ContentTypes["FWAMOU CT"]
    
    write-log -message "Remove Source Facility Name From FWAMOU CT" -consoleForeground Gray
    #get the column from the web
    $spFieldLink = New-Object Microsoft.SharePoint.SPFieldLink ($w.Fields["Source Facility Name"])
    #Remove the field from the ct and update
    $ct.FieldLinks.Delete($spFieldLink.Id)
    
    write-log -message "Remove Partner Facility Name From FWAMOU CT" -consoleForeground Gray  
    $spFieldLink = New-Object Microsoft.SharePoint.SPFieldLink ($w.Fields["Partner Facility Name"])
    #Remove the field from the ct and update
    $ct.FieldLinks.Delete($spFieldLink.Id)
    $ct.Update($true)

    $fwamoulist = $w.Lists["FWAMOU"]
    $fwamouCT = $w.ContentTypes["FWAMOU CT"]
    $fwamoulist.ContentTypes.Add($fwamouCT) | write-log -consoleForeground white
    $fwamoulist.ContentTypes["Item"].Delete()
    $fwamouCT.Update() 
    $fwamoulist.Update()
    $w.Update()

    write-log -message "Added $($fwamouCT.Name) to $($fwamoulist.Title) [$($fwamoulist.RootFolder)] on $($w.url)" -consoleForeground Gray
    AdjustContentTypeOrder $fwamoulist
}

function AdjustContentTypeOrder ($list) {
    #$ct = $list.ContentTypes["FWAMOU CT"] 
    $ct = $w.ContentTypes["FWAMOU CT"]

    $fldList = @(
        "Title",
         "SourceSiteName",
         "PartnerSiteName",
         "FWAMOUDocumentType",
         "ApprovalOrEffectiveDate",
         "ExpirationDate",
         "RenewalDate",
         "FWAMOUNotes",
         "FWANumber",
         "FWASignatoryOfficial",
         "MOUAmendmentNumber",
         "MOUDateAmendmentReceived",
         "MOUReasonforAmendment"
    )
    $ct.FieldLinks.Reorder($fldList)
    $ct.Update($true)
}

function MigrateFWAMOUItems($url) {
    
    try {
        write-log -message "$([String]::Format("Procesing web {0}",$w.Url))" -consoleForeground White
        write-log -message "MOVING FWAMOU OLD FIELDS TO FWAMOU LIST" -consoleForeground Green
        #Read needed items from the old facilit
        $oldFWAMOUList = $w.Lists.TryGetList("OldFWAMOU")
        $fwamoulist =$w.Lists["FWAMOU"]
        
        write-log -message "Migrating $($oldFWAMOUList.ItemCount) $($fwamoulist.Title) records" -consoleForeground White
        foreach($oldItem in $oldFWAMOUList.Items) {
            Write-log -message "Migrating old record: $($oldItem.Title)" -consoleForeground Gray
            $newItem = $fwamoulist.AddItem()  
            #$newItem = $fwamoulist.Items.Add()  
            
            if ($oldItem["Title"] -ne $null) {
                $newItem["Title"] = [string]$oldItem["Title"]
            }
            
            $fwamouFacilitySourceLookup = $oldItem["FWAMOUSource"]
            $fwamouFacilityPartnerLookup = $oldItem["FWAMOUPartner"]
            
            if ($fwamouFacilitySourceLookup -ne $null) {
                $fwamouFacilitySourceLookupIndex = $fwamouFacilitySourceLookup.IndexOf("#") + 1
                $fwamouFacilitySourceLookupTitle = $fwamouFacilitySourceLookup.substring($fwamouFacilitySourceLookupIndex)
                $fwamouFacilitySourceLookupItem =GetFacilitiesItem($fwamouFacilitySourceLookupTitle)
            }
            
            if ($fwamouFacilityPartnerLookup -ne $null) {
                $fwamouFacilityPartnerLookupIndex = $fwamouFacilityPartnerLookup.IndexOf("#") + 1
                $fwamouFacilityPartnerLookupTitle = $fwamouFacilityPartnerLookup.substring($fwamouFacilityPartnerLookupIndex)
                $fwamouFacilityPartnerLookupItem = GetFacilitiesItem($fwamouFacilityPartnerLookupTitle)
            }
            
            if ($fwamouFacilitySourceLookupItem.ID -ne $null) {
                $newItem["SourceSiteName"] = [int]$fwamouFacilitySourceLookupItem.ID
            }
            
            if ($fwamouFacilityPartnerLookupItem -ne $null) {
                $newItem["PartnerSiteName"] = [int]$fwamouFacilityPartnerLookupItem.ID
            }

            if ($oldItem["FWAMOUDocumentType"] -ne $null) {
                $newItem["FWAMOUDocumentType"] = [String]$oldItem["FWAMOUDocumentType"]
            }
            
            if ($oldItem["ApprovalOrEffectiveDate"] -ne $null) {
                $newItem["ApprovalOrEffectiveDate"] = [DateTime]$oldItem["ApprovalOrEffectiveDate"]
            }
            
            if($oldItem["ExpirationDate"] -ne $null) {
                $newItem["ExpirationDate"] = [DateTime]$oldItem["ExpirationDate"]
            }
            
            if($oldItem["RenewalDate"] -ne $null) {
                $newItem["RenewalDate"] = [DateTime]$oldItem["RenewalDate"]
            }
            
            if($oldItem["FWAMOUNotes"] -ne $null) {
                $newItem["FWAMOUNotes"] = [String]$oldItem["FWAMOUNotes"]  
            }
            
            if($oldItem["FWANumber"] -ne $null) {
                $newItem["FWANumber"] = [String]$oldItem["FWANumber"]
            }
            
            if($oldItem["FWASignatoryOfficial"] -ne $null) {
                $newItem["FWASignatoryOfficial"] = [String]$oldItem["FWASignatoryOfficial"]  
            }
            
            if($oldItem["MOUAmendmentNumber"] -ne $null) {
                $newItem["MOUAmendmentNumber"] = [string]$oldItem["MOUAmendmentNumber"] 
            }
            
            if($oldItem["MOUDateAmendmentReceived"] -ne $null) {
                $newItem["MOUDateAmendmentReceived"] = [DateTime]$oldItem["MOUDateAmendmentReceived"]  
            }   
            
            if($oldItem["MOUReasonforAmendment"] -ne $null) {
               $newItem["MOUReasonforAmendment"] = [string]$oldItem["MOUReasonforAmendment"] 
            }
                       
            $newItem.Update()
            write-log -message "New item has been added to FWAMOU." -consoleForeground Green
        }
    } catch {
        write-log -message "$([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message))" -consoleForeground Red
        if ($($_.Exception -ne $null)) {
            $exception = $_.Exception
            write-log -message "$($exception.GetType().FullName)" -consoleForeground Red
            if (([pscustomobject]$exception.psobject.properties.match('Message')) -and $($exception.Message) -ne $null) { write-log -message "$($exception.Message)" -consoleForeground Red }
            if (([pscustomobject]$exception.psobject.properties.match('ErrorRecord')) -and $($exception.ErrorRecord) -ne $null) { write-log -message "$($exception.ErrorRecord)" -consoleForeground Red }
            if (([pscustomobject]$exception.psobject.properties.match('stacktrace')) -and $($exception.stacktrace) -ne $null) { write-log -message "$($exception.stacktrace)" -consoleForeground Red }
        } else {
            write-log -message "$exception" -consoleForeground Red
        }
        if (([pscustomobject]$_.psobject.properties.match('ScriptStackTrace')) -and $($_.ScriptStackTrace -ne $null)) { write-log -message "$($_.ScriptStackTrace)" -consoleForeground Red }
    }

}

function GetFacilitiesItem ($title) {
    $facilitiesList = (Get-SiteWeb).Lists.TryGetList("Facilities")
    $spListItem =  $facilitiesList.Items | ? {$_["Title"] -match $title}
    return $spListItem;
}

function createFWAMOUStandardView () {
    $list = (Get-SiteWeb).Lists.TryGetList("FWAMOU")
    $fldList = @(
        'LinkTitle';
        'PartnerSiteName';
        'FWANumber';
        'ApprovalOrEffectiveDate'; 
        'ExpirationDate'
    )
    $viewQuery = "<Where></Where>"
    New-SpListView -fldList $fldList -viewTitle 'StandardView' -listName 'FWAMOU' -viewQuery $viewQuery -viewRowLimit '50'
    $view=$list.Views["StandardView"]
    $view.DefaultView = $true
    $view.MobileView = $true
    $view.MobileDefaultView = $true
    $view.Update()
}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://DNS.URL/sites/IRBApplications/";
write-log -message "Update and Migrate FWAMOU List Data" -consoleForeground Cyan
$w = Get-SPWeb $siteUrl
CreateFWAFacilityLookups
AddSiteColumnsToContentType

RecreateList 
#MigrateFWAMOUItems($siteUrl)
createFWAMOUStandardView
