<#

.SYNOPSIS
    Populates the Off-site-Waiver Requests field from Study Answers.

.DESCRIPTION
    Executes the GetWaiverDetails stored procedure to retrieve the Off-site-Waiver Requests by study
    For each study returned, populates the Off-site-Waiver Requests column.

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 090 MigrateMigrateOffsiteWaiverData.ps1

.EXAMPLE
    #when run from command line
    .\MigrateMigrateOffsiteWaiverData.ps1
#>
$applicationList = (Get-SiteWeb).Lists.TryGetList("Application")
$result = Invoke-Sqlcmd -ServerInstance ($Global:hostInfo.sql) -Database RAMS   -Query "exec GetWaiverDetails"

$result | % {
   $ID = $_.SPListItem
   $Response = $_.Response
   $spListItem =  $applicationList.Items | ? {$_["ID"] -match $ID}
   if($spListItem) {
       $spListItem["Off-site Waiver Requests"] = $Response
       $spListItem.Update()
       write-log -message "Offsite Waiver has been updated for: $($spListItem["Study_ID"]), $ID, $Response" -consoleForeground Cyan
   }
}









