<#

.SYNOPSIS
  Updates the new Committee Statuses.

.DESCRIPTION
    This builds the list of committee statuses so they can be used in a lookup. The statuses include 
    "Approved", "Approved with Major Modifications", "Approved with Minor Modifications", "Awaiting Revisions",
    "Closed", "Disapproved", "Draft", "Submitted", "Suspended", and "Under Review"

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 020 NewCommitteeStatus.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\NewCommitteeStatus.ps1
#>

$weburl = Get-SiteURL
$webSite = Get-SiteWeb

#create new list
$listTemplate = $webSite.ListTemplates | ? {$_.InternalName -match "custlist"}
$webSite.Lists.Add("CommitteeStatus","CommitteeStatus", $listTemplate)
$CommitteesList = $webSite.Lists.TryGetList("CommitteeStatus")

$statusValues = @(
    "Approved"
    ,"Approved with Major Modifications"
    ,"Approved with Minor Modifications"
    ,"Awaiting Revisions"
    ,"Closed"
    ,"Disapproved"
    ,"Draft"
    ,"Submitted"
    ,"Suspended"
    ,"Under Review"
)
$statusValues | % {
    $newItem = $CommitteesList.Items.Add()
    $newItem["Title"] = $_
    $newItem.Update()
}
$CommitteesList.Update()

#create new view
$fldList = @(
"ID",
"Title"
)
$CommitteesList.Views.Add("CommitteesStatusView",$fldList,"",100,$True,$True) | write-log -consoleForeground Gray
$CommitteesView = $CommitteesList.Views["CommitteesStatusView"]
#set sort order
$orderBy = "
<OrderBy>
    <FieldRef Name='Title' Ascending='True'/>    
</OrderBy>"
$CommitteesView.Query = $orderBy
$CommitteesView.Update()

#Turn on versioning for the Facility List
$CommitteesList.EnableVersioning = $true
$CommitteesList.EnableMinorVersions = $false

$webSite.Update()
