<#

.SYNOPSIS
    Adds R2.3 fields to the new Facilities list.

.DESCRIPTION
    Creates the AnimalFacilityManagers, Local SiteLiaisons, localSiteAdministrators, FacilitySubsite, Audience, and 
    TaxWord
    Adds the AnimalFacilityManagers, Local SiteLiaisons, localSiteAdministrators, FacilitySubsite, Audience, and 
    TaxWord to the Facility Content Type. 
    Adds the SC1, SC2, and SC3 committees to the committeeTypes list.
    For each facility in the Facility List, create the AnimalFacilityManager and SC1-SC3 security groups
    Creates the new Facilities List and migrates the data from the old list (now renamed to Old Facility)
    Moves the facility level data from the committe list to the new Facilities list.

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 030 NewFacilityInfo.ps1

.EXAMPLE
    #when run from command line
    .\NewFacilityInfo.ps1
#>
$weburl = Get-SiteURL
$webSite = Get-SiteWeb

#Add new site columns
Set-SiteColumn -web $webSite -sFieldDisplayName "Animal Facility Managers" -sFieldStaticName "AnimalFacilityManagers" -sFieldInternalName "AnimalFacilityManagers" -sFieldType User -spFieldGroup "RAMS IRB"

#Add site columns to facility CT
write-log -message "ADDING SITECOLUMNS TO FACILITY CONTENT TYPE" -consoleForeground Green
Add-SiteColumnToCT -web $webSite -ctName "Facility CT" -sFieldInternalName "AnimalFacilityManagers" -sFieldStaticName "AnimalFacilityManagers"
Add-SiteColumnToCT -web $webSite -ctName "Facility CT" -sFieldInternalName "LocalSiteLiaisons" -sFieldStaticName "LocalSiteLiaisons"
Add-SiteColumnToCT -web $webSite -ctName "Facility CT" -sFieldInternalName "LocalSiteAdministrators" -sFieldStaticName "LocalSiteAdministrators"
Add-SiteColumnToCT -web $webSite -ctName "Facility CT" -sFieldInternalName "FacilitySubsite" -sFieldStaticName "FacilitySubsite"
Add-SiteColumnToCT -web $webSite -ctName "Facility CT" -sFieldInternalName "Audience" -sFieldStaticName "Audience"
Add-SiteColumnToCT -web $webSite -ctName "Facility CT" -sFieldInternalName "TaxKeyword" -sFieldStaticName "TaxKeyword"

$facilityCT = $webSite.ContentTypes | ? {$_.Name -match "Facility CT"}
$facilityCT.Fields | ? {$_.Title -match "Facility Administrators"} | ? {$_.Title = "Local Site Administrators"}| ? {$_.Update()} 

#add new committee's to Committee Type list
$committeeType = $webSite.Lists.TryGetList("Committee Types")

$newItem = $committeeType.AddItem()
$newItem["CommitteeID"] = 5
$newItem["CommitteesName"] = "SC1"
$newItem["CommitteeCode"] = 105
$newItem["Description"] = "Supplemental Committee 1"
$newItem.Update()

$newItem = $committeeType.AddItem()
$newItem["CommitteeID"] = 6
$newItem["CommitteesName"] = "SC2"
$newItem["CommitteeCode"] = 106
$newItem["Description"] = "Supplemental Committee 2"
$newItem.Update()

$newItem = $committeeType.AddItem()
$newItem["CommitteeID"] = 7
$newItem["CommitteesName"] = "SC3"
$newItem["CommitteeCode"] = 107
$newItem["Description"] = "Supplemental Committee 3"
$newItem.Update()

$committeeType.Update()


#rename current facility list
$oldList = $webSite.Lists.TryGetList("Facility")
$oldList.items | ForEach-Object {
    New-RAMSGroup -facility $_.Title -newGroupName "Animal Facility Managers" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Animal Facility Managers"
    New-RAMSGroup -facility $_.Title -newGroupName "SC1 Administrators" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 1 Administrators"
    New-RAMSGroup -facility $_.Title -newGroupName "SC2 Administrators" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 2 Administrators"
    New-RAMSGroup -facility $_.Title -newGroupName "SC3 Administrators" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 3 Administrators"

    New-RAMSGroup -facility $_.Title -newGroupName "SC1 Committee Coordinators" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 1 Coordinators"
    New-RAMSGroup -facility $_.Title -newGroupName "SC2 Committee Coordinators" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 2 Coordinators"
    New-RAMSGroup -facility $_.Title -newGroupName "SC3 Committee Coordinators" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 3 Coordinators"

    New-RAMSGroup -facility $_.Title -newGroupName "SC1 Committee Members" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 1 Members"
    New-RAMSGroup -facility $_.Title -newGroupName "SC2 Committee Members" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 2 Members"
    New-RAMSGroup -facility $_.Title -newGroupName "SC3 Committee Members" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Supplemental Committee 3 Members"

}
#add new security groups
Add-FacilityGroup -newGroupName "Animal Facility Managers" -newGroupPermission "Edit" 
Add-FacilityGroup -newGroupName "SC1 Administrators" -newGroupPermission "Edit" 
Add-FacilityGroup -newGroupName "SC2 Administrators" -newGroupPermission "Edit" 
Add-FacilityGroup -newGroupName "SC3 Administrators" -newGroupPermission "Edit" 

Add-FacilityGroup -newGroupName "SC1 Committee Coordinators" -newGroupPermission "Edit" 
Add-FacilityGroup -newGroupName "SC2 Committee Coordinators" -newGroupPermission "Edit" 
Add-FacilityGroup -newGroupName "SC3 Committee Coordinators" -newGroupPermission "Edit" 

Add-FacilityGroup -newGroupName "SC1 Committee Members" -newGroupPermission "Edit" 
Add-FacilityGroup -newGroupName "SC2 Committee Members" -newGroupPermission "Edit" 
Add-FacilityGroup -newGroupName "SC3 Committee Members" -newGroupPermission "Edit" 

#Update view permission on the SC groups
(Get-SiteWeb).SiteGroups | ? {$_.Owner -match "Local Site Administrators"}| % {
    $_.OnlyAllowMembersViewMembership = $False
    $_.Update()
}

#rename current facility list to old list
$oldList.Title = "Old Facility"
$oldList.RootFolder.MoveTo("OldFacility")
$webSite.Update()

#create new facility list
$listTemplate = $webSite.ListTemplates | ? {$_.InternalName -match "custlist"}
$webSite.Lists.Add("Facilities","Facilities", $listTemplate)
$facilityList = $webSite.Lists.TryGetList("Facilities")
$facilityCT = $webSite.ContentTypes["Facility CT"]
$facilityList.ContentTypes.Add($facilityCT) | write-log -consoleForeground Gray

#set required fields
$requiredFldList = @(
    "Site Code",
    "Facility Location",
    "Facility Subsite",
    "Facility Liaison",
    "Facility Users",
    "Administrative Officers",
    "Research Compliance Officers",
    "Local Site Liaisons",
    "Local Site Administrators",
    "Animal Facility Managers"
)
$requiredFldList | % {
    $field = $facilityList.Fields.GetField($_)
    $field.Required = $True
    $field.ShowInEditForm = $True
    $field.ShowInNewForm = $True
    $field.Update()
}
$facilityList.Update()
 
#add new view
$fldList = @("ID",
    "Title",
    "Site Code",
    "Facility Location",
    "Facility Subsite",
    "Facility Liaison",
    "Facility Users",
    "Administrative Officers",
    "Research Compliance Officers",
    "Local Site Liaisons",
    "Local Site Administrators",
    "Animal Facility Managers"
)

#enable management of content type
$facilityList.ContentTypesEnabled = $True
<#
$facilityList.Fields | % {
    $_.ShowInEditForm = $True
    $_.ShowInNewForm = $True
    $_.ShowInDisplayForm = $True
    $_.Update()
}
#>
$facilityList.Update()

#show fields on the form.
$fldList | % {
    $formField = $facilityList.Fields.GetField($_)
    $formField.ShowInEditForm = $True
    $formField.ShowInNewForm = $True
    $formField.ShowInDisplayForm = $True
    $formField.Update()
}
$facilityList.Update()
#create new view
$facilityList.Views.Add("FacilitiesView",$fldList,"",100,$True,$True) | write-log -consoleForeground Gray
$facilityView = $facilityList.Views["FacilitiesView"]
#set sort order
$orderBy = "
<OrderBy>
    <FieldRef Name='Title' Ascending='True'/>
</OrderBy>"
$facilityView.Query = $orderBy
$facilityView.Update()

write-log -message "MOVING COMMITTEE LIST FIELDS TO FACILITY LIST" -consoleForeground Green
#Read needed items from the old facility 
$oldFacilityList = $webSite.Lists.TryGetList("OldFacility")
foreach($oldFacility in $oldFacilityList.Items) {
        $newItem = $facilityList.AddItem()                    
        $newItem["Title"] = $oldFacility["Title"]
        $newItem["FacilityLocation"] = $oldFacility["FacilityLocation"]
        $newItem["FacilitySubsite"] = $oldFacility["FacilitySubsite"]
        $newItem["FacilityLiaison"] = $oldFacility["FacilityLiaison"]
        $newItem["CommitteeLookup"] = $oldFacility["CommitteeLookup"]
        $newItem["FacilitySubsite"] = $oldFacility["FacilitySubsite"]
        $newItem["Facility Users"] = $oldFacility["Users"]

        $newItem["AdministrativeOfficers"] = $oldFacility["AdministrativeOfficers"]    
        $newItem["ResearchComplianceOfficers"] = $oldFacility["ResearchComplianceOfficers"]
        $newItem["LocalSiteLiaisons"] = $oldFacility["LocalSiteLiaisons"]     
        $newItem["LocalSiteAdministrators"] = $oldFacility["LocalSiteAdministrators"]   
            
        $newItem.Update()
        write-log -message "New data for:$($oldFacility['FacilityName']) has been added." -consoleForeground Green    
}

#Copy certain fields from committee list
$committeeList = $webSite.Lists.TryGetList("Committee list")
foreach ($facility in $facilityList.Items) {
    foreach($commitee in $committeeList.Items) {
        if($commitee["Title"] -eq $facility["Title"]) {
            $facility["LocalSiteAdministrators"] = $commitee["LocalSiteAdministrators"]
            $facility["LocalSiteLiaisons"] = $commitee["LocalSiteLiaisons"]
            $facility["AnimalFacilityManagers"] = ($website.Groups["$($commitee['Title']) Animal Facility Managers"]).ID
        }
    }
}


#Turn on versioning for the Facility List
$facilityList.EnableVersioning = $true
$facilityList.EnableMinorVersions = $false

$webSite.Update()

#clean
if($webSite -ne $null) {
    $webSite.Dispose();
}