<#

.SYNOPSIS
    Creates the R2.3 SSRS list.

.DESCRIPTION
    Creates the SSRS Content Type, adds it to the Reports List, Updates the views, and updates the list.

.NOTES
    This is the first step in turning on SSRS integrated mode.

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 230 NewSSRSList.ps1

.EXAMPLE
    #when run from command line
    .\NewSSRSList.ps1
#>

$weburl = Get-SiteURL
$webSite = Get-SiteWeb

#CT
$ssrsCT = New-Object Microsoft.SharePoint.SPContentType($webSite.AvailableContentTypes["Report"],$webSite.ContentTypes,"SSRS CT")
$webSite.ContentTypes.Add($ssrsCT)
$webSite.Update()

#list
$listTemplate = $webSite.ListTemplates | ? {$_.InternalName -match "custlist"}
$webSite.Lists.Add("Reports","Reports", $listTemplate)
$ReportsList = $webSite.Lists.TryGetList("Reports")
$SSRSCT = $webSite.ContentTypes["SSRS CT"]
$ReportsList.ContentTypes.Add($SSRSCT) | write-log -consoleForeground Gray
$ReportsList.Update()

#view
$fldList = @(
"Name",
"Title",
"Document Modified By",
"Document Created By",
"Report Description",
"Report Category",
"Report Status"
)

$ReportsList.Views.Add("ReportsView",$fldList,"",100,$True,$True) | write-log -consoleForeground Gray
$ReportsView = $ReportsList.Views["ReportsView"]
$ReportsView.DefaultView = $True
$ReportsView.MobileDefaultView = $True
$ReportsView.MobileView = $True
$ReportsView.Update()
$ReportsList.Update()

#show in new form and edit form.
$fldList = @(
"Name",
"Title",
"Document Modified By",
"Document Created By",
"Report Description",
"Report Category",
"Report Status"
)
#name field
$formField = $ReportsList.Fields.GetField("Name")
$formField.ShowInDisplayForm = $True
$formField.ShowInEditForm = $True
$formField.ShowInNewForm = $True
$formField.Update()
#name field
$formField = $ReportsList.Fields.GetField("Document Modified By")
$formField.ShowInDisplayForm = $True
$formField.ShowInEditForm = $True
$formField.ShowInNewForm = $True
$formField.Update()
#name field
$formField = $ReportsList.Fields.GetField("Document Created By")
$formField.ShowInDisplayForm = $True
$formField.ShowInEditForm = $True
$formField.ShowInNewForm = $True
$formField.Update()
#field update
$formField = $ReportsList.Fields.GetField("Report Description")
$formField.ShowInDisplayForm = $True
$formField.ShowInEditForm = $True
$formField.ShowInNewForm = $True
$formField.Update()
#field update
$formField = $ReportsList.Fields.GetField("Report Category")
$formField.ShowInDisplayForm = $True
$formField.ShowInEditForm = $True
$formField.ShowInNewForm = $True
$formField.Update()
#field update
$formField = $ReportsList.Fields.GetField("Report Status")
$formField.ShowInDisplayForm = $True
$formField.ShowInEditForm = $True
$formField.ShowInNewForm = $True
$formField.Update()


#Turn on versioning for the Facility List
$ReportsList.EnableVersioning = $true
$ReportsList.EnableMinorVersions = $false
$ReportsList.Update()
$webSite.Update()

#clean
if($webSite -ne $null) {
    $webSite.Dispose();
}