<#
.SYNOPSIS
    Schedule the MigrateFacilityDataScheduleTask as a recurring task
    
.DESCRIPTION
    Creates scheduled task to run the MigrateFacilityDataScheduleTask every 10 minutes on the server where it is run.
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 380 ScheduleTask.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\ScheduleTask.ps1
  
#>
$migrateFile = $fileLocationPS + 'MigrateFacilityDataScheduleTask.ps1'

$migrateFile = $migrateFile + ' -localSiteUrl ' + $siteUrl 


$action = New-ScheduledTaskAction -Execute 'Powershell.exe' -Argument $migrateFile 

try {
    Unregister-ScheduledTask -TaskName "MigrateFacilityDataScheduleTask" -Confirm:$false
} catch {
  write-log -message "Task Already Exist" -consoleForeground Yellow
}

$trigger = New-ScheduledTaskTrigger -Once -At (Get-Date) -RepetitionInterval (New-TimeSpan -Minutes 10) -RepetitionDuration ([System.TimeSpan]::MaxValue)

$settings = New-ScheduledTaskSettingsSet -Hidden -AllowStartIfOnBatteries -DontStopIfGoingOnBatteries -StartWhenAvailable -RunOnlyIfNetworkAvailable

$UserName = $Global:farmUserID
$Password = $Global:farmPwd


Register-ScheduledTask -Action $action -Trigger $trigger -TaskName "MigrateFacilityDataScheduleTask" -User $UserName -Password $Password -Description "MigrateFacilityData" -Settings $settings | write-log -consoleForeground Gray

write-log -message "Task Scheduled" -consoleForeground Green


