<#
.SYNOPSIS
    Turns off Throttling for the Application List
    
.DESCRIPTION
    Turns off the SharePoint Throttling of the Application list due to the large number of records on the list.
    
.NOTES
    This allows the application list to not have a limit on the number of filters within a CAML Query. 
    If this is not changed the default limit is 20. Not sure if there is a way to limit per list.  The other option was 
    to change the limit for everything. This could cause performence issues with large and inefficient queries. 
    Research said indexes could be placed on the Title column.

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 270 TurnOffApplicationListThrottling.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\TurnOffApplicationListThrottling.ps1
  
#>


$weburl = Get-SiteURL
$webSite = Get-SPWeb $weburl
$mySPList = $webSite.Lists["Application"]
$mySPList.EnableThrottling = $false
$mySPList.Update()