<#
.SYNOPSIS
    Updated the Application list for R2.3.
    
.DESCRIPTION
    Builds the Participating Facilities lookup field
    Adds ParticipatingFacilitiesLookup and FacilitiesLookup to the Application Content Type
    Moves the data from the FacilityLookup to the FacilitiesLookup, for each record that has a value. 
    Moves the data from the ParticipatingFacilityLookup to the ParticipatingFacilitiesLookup, for each record that has a value. 
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 060 UpdateApplicationList.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\UpdateApplicationList.ps1
  
#>

#add new site column
Set-SiteColumnLookup -web (Get-SiteWeb) -colName "Participating Facilities Lookup" -colStaticName "ParticipatingFacilitiesLookup" -lookupListName "Facilities" -lookupColumnName "Title" 

#add columns to application CT
Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "ParticipatingFacilitiesLookup" -sFieldStaticName "ParticipatingFacilitiesLookup"
Add-SiteColumnToCT -web (Get-SiteWeb) -ctName "Application CT" -sFieldInternalName "FacilitiesLookup" -sFieldStaticName "FacilitiesLookup"

#get list
$applicationList = (Get-SiteWeb).Lists.TryGetList("Application")
$facilitiesList = (Get-SiteWeb).Lists.TryGetList("Facilities")

#data migration [Facility Lookup ==> FacilitiesLookup]
write-log -message "Building lookup dictionary of $($facilitiesList.ItemCount) facilities" -consoleForeground Cyan
write-log -message "Migrating Facilities on $($applicationList.ItemCount) application Items" -consoleForeground Cyan
write-log -message "  This is 3 different data migrations that in testing took ~45-60 minutes for 2000 records" -consoleForeground Gray
$appItems = New-Object -TypeName 'System.Collections.Generic.Dictionary[System.String,System.String]'
$facilitiesList.Items | % {
    $title = $_["Title"]
    $applicationList.Items | % {
    if($_["Facility Lookup"] -match $title) {
            $appItems[$_.ID] = $title
       }
    }
}
$cnt = $appItems.Count
$dotCount = 0
write-log -message "  Migrating $cnt application Faciltities Lookups..." -consoleForeground Cyan
$appItems.keys | % {
    if ($dotCount -lt 100) {
        Write-Host "." -NoNewline -foregroundColor Gray
        $dotCount++ 
    } else {
        write-log -message "." -consoleForeground Gray
        $dotCount = 0
    }
    $ID = $_
    $FacilityTitle = $appItems.Item($ID)
    $updateItem = $applicationList.Items | ? {$_.ID -eq $ID}
    if($updateItem -ne $null) {
        $facilitiesLookup = $facilitiesList.Items | ? {$_.Title -eq $FacilityTitle}
        $updateItem["Facilities Lookup"] = $facilitiesLookup.ID
        $updateItem.Update()
    }
}
write-log -message "." -consoleForeground Gray
$applicationList.Update()

#data migration [Participating Site ==> Participating Facilities Lookup]
$cnt = $facilitiesList.ItemCount
$dotCount = 0
write-log -message "  Migrating $cnt application Participating Site Lookups..." -consoleForeground Cyan
$appItems = New-Object -TypeName 'System.Collections.Generic.Dictionary[System.String,System.String]'
$facilitiesList.Items | % {
    if ($dotCount -lt 100) {
        Write-Host "." -NoNewline -foregroundColor Gray
        $dotCount++
    } else {
        write-log -message "." -consoleForeground Gray
        $dotCount = 0
    }
    $title = $_["Title"]
    $applicationList.Items | % {
    if($_["Participating Site"] -match $title) {
            $appItems[$_.ID] = $title
       }
    }
}
write-log -message "." -consoleForeground Gray

$cnt = $appItems.Count
$dotCount = 0
write-log -message "  Migrating $cnt application Participating Facilities Lookups..." -consoleForeground Cyan
$appItems.keys | % {
    if ($dotCount -lt 100) {
        Write-Host "." -NoNewline -foregroundColor Gray
        $dotCount++
    } else {
        write-log -message "." -consoleForeground Gray
        $dotCount = 0
    }
    $ID = $_
    $FacilityTitle = $appItems.Item($ID)
    $updateItem = $applicationList.Items | ? {$_.ID -eq $ID}
    if($updateItem -ne $null) {
        $facilitiesLookup = $facilitiesList.Items | ? {$_.Title -eq $FacilityTitle}
        $updateItem["Participating Facilities Lookup"] = $facilitiesLookup.ID
        $updateItem.Update()
    }
}
write-log -message "." -consoleForeground Gray
$applicationList.Update()

#update the view
write-log -message "  Updating the Administrative View..." -consoleForeground Cyan
$adminView = $applicationList.Views["Administrative"]
$adminView.ViewFields.Add("Participating Facilities Lookup")
$adminView.ViewFields.Add("Facilities Lookup")
if($adminView.ViewFields | ? {$_ -match "FacilityLookup"}) {
    $adminView.ViewFields.Delete("FacilityLookup")
}
$adminView.Update()



