<#
.SYNOPSIS
    Updated the URL in all the environment lists.
    
.DESCRIPTION
    Loops through the environment list at the site collection level and at the subsite level to update the URL for the 
    environment. 
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 010 UpdateEnvironmentList.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\UpdateEnvironmentList.ps1
  
#>
Add-PSSnapin Microsoft.SharePoint.PowerShell
#RTC file Named "UpdateEnvironmentList"
#Updateds Environment List at site collection level to contain the correct details to be used by workflows
$spWeb = Get-SiteWeb 
$siteURL = Get-SiteURL
$SpSite = Get-SpSite -Identity $siteURL

#Update this file to point to the domain name like
$EnvironmentDomainName=$siteURL

# Get the root web
$rootWeb = $siteURL.Replace($SpSite.ServerRelativeUrl, "")

$facilities = @{
}


function UpdateEnvironmentList($w) 
{

    $list = $w.GetList($w.URL.TrimEnd("/") + "/Lists/Environment")

    $recordsUpdated=0
    #clean the existing record
    if ($list.Items.Count -gt 0) {         
        foreach ($item in $list.Items)
        {
            $list.Items.DeleteItemById($item.ID)
        }
    }
    $list.Update()
    $newItem = $list.additem()
    $newitem["Title"] = "Environment"
    $newitem["URL"] = $rootweb
    
    #add the site column if it's missing in the list
    if($list.Fields.ContainsFieldWithStaticName("Site") -eq $False) {
        $list.Fields.Add("Site", "Text", $True)
    }
    $newItem["Site"] = $facilities.Item($w.Url);
        
    $newitem.Update()
    $list.Update()
    write-log -message "  $($newitem["Title"]) added URL $rootWeb on site $w" -consoleForeground White
    $recordsUpdated+=1
    
    write-log -message "  Records updated: $recordsUpdated on site $w" -consoleForeground Green
    #update the view to include Site column
    $list.Views["All Items"].ViewFields.Add("Site");

}

  function getAllFacilities ($web)
   {
  
    #Get the Source List
    $facilityList = $web.Lists["Facility"]
    $facilityitems = $facilityList.items
    
    foreach($facilityItem in $facilityitems)
    {
        $facilityName=$facilityItem["FacilityName"]
        $fldurl=new-object Microsoft.SharePoint.SPFieldUrlValue($facilityItem["FacilitySubsite"])
        $facilitySubsite=$fldurl.URL
        $facilityId=$facilityItem["ID"]
        write-log -message "Adding facilities Name=$facilityName ID=$facilityId URL=$facilitySubsite" -consoleForeground White
        $facilities.add($facilitySubsite, $facilityName)
    }
}


getAllFacilities -web $spWeb 
UpdateEnvironmentList -w $spWeb

foreach($w in $spWeb.Webs) 
{    
   UpdateEnvironmentList -w $w
}

