<#
.SYNOPSIS
    UpdateGroupViewPermission updates security group permissions.
    
.DESCRIPTION
    Loops through all security groups defined at the site collection level and subsite level, allowing the members of
    the group to view the group membership. If this is not done, RAMS users would not be able to select members from
    the drop downs and the security checks would not work. 
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 280 UpdateGroupViewPermission.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\UpdateGroupViewPermission.ps1
  
#>

$rootSite = (Get-SiteWeb)

#group permissions at site collectioon level
$rootSite.Groups | % {
    $_.OnlyAllowMembersViewMembership = $False
    $_.Update()
    write-log -message "'Allow Members View Membership' has been updated for $($_.Name)" -consoleForeground Yellow    
}
$rootSite.Update()

#group permissions at facility level
$rootSite.Webs | % {
    $groups = $_.Groups
    $site = $_
    $groups | % {
        $_.OnlyAllowMembersViewMembership = $False
        $_.Update()
        write-log -message "'Allow Members View Membership' has been updated for $($_.Name)" -consoleForeground Yellow
    }
    $site.Update()
}

