<#
.SYNOPSIS
    Updates the Local Site Administrator to add the Manage Permissions permission.
    
.DESCRIPTION
    Loops webs and adds the Manage Permissions permission to the Local Site Administrator security group so that when 
    the LSA adds a person to a security group, that person can be notified by email.  
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 350 UpdateLSAGroupPermission.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\UpdateLSAGroupPermission.ps1
 #>
$web = Get-SiteWeb
$facilityList  = $web.lists["Facilities"]

$permname = "Manage Permissions"
$permDesc = "Allows users to add users to security groups and sends the resulting email when requested"

#create role def
$roledef = New-Object Microsoft.SharePoint.SPRoleDefinition

$roledef.BasePermissions = ("ManagePermissions","Open","BrowseUserInfo","Enumeratepermissions","ViewPages","BrowseDirectories","ViewVersions","OpenItems","ViewListItems")
#[enum]::GetValues([Microsoft.SharePoint.SPRights]) | ?{$_.value__ -band $roledef.BasePermissions}
$roledef.Name = $permname
$roledef.Description = $permDesc
$web.RoleDefinitions.Add($roledef)
write-log -message "Creating the $($roledef.Name) role definition" -consoleForeground Green
$web.Update()

$web.webs | % {
    $FacilityWeb = $_
    $managePermissionRole = $web.RoleDefinitions[$permname]
    $facilityName = $facilityList.Items | ? {$_["Facility Subsite"] -match "$($FacilityWeb.Name)"} | % {$_["Title"]}
    $LSAGroup = $web.SiteGroups.GetByName("$facilityName Local Site Administrators")
    $groupRole = New-Object Microsoft.SharePoint.SPRoleAssignment($LSAGroup)
    $groupRole.RoleDefinitionBindings.Add($managePermissionRole)
    $web.RoleAssignments.Add($groupRole)
    write-log -message "Updating the $($LSAGroup.Name) to also have the $($roledef.Name) role" -consoleForeground Green
    $web.Update()
}

