<#
.SYNOPSIS
    Updates the SubmittedApplications calculated field in the ApplicationFacilityLookup list.
    
.DESCRIPTION
    Loops through all subsites and updates the SubmittedApplications calculated field in the ApplicationFacilityLookup list.  
    
.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 320 UpdateSubmittedColumn.ps1

.EXAMPLE
    #when run from the powershell command prompt.
    .\UpdateSubmittedColumn.ps1
 #>

Add-PSSnapin Microsoft.SharePoint.Powershell

function GetAllWebs($url)
{
    try
    {
        write-log -message "$([String]::Format("Procesing web {0}",$w.Url))" -consoleForeground Cyan
    
        if($w.Webs.Count -gt 0)
        {
            foreach($web in $w.Webs)
            {
               UpdateSubmittedCalculatedField $web
             }
        }
    }
    catch
    {
        write-log -message "$([String]::Format("Error processing web at $url, with Exception: {0}", $_.Exception.Message))" -consoleForeground Red
        if ($($_.Exception.ErrorRecord)) { write-log -message "$($_.Exception.ErrorRecord)" -consoleForeground Red }
        if ($($_.Exception.stacktrace)) { write-log -message "$($_.Exception.stacktrace)" -consoleForeground Red }
        if ($($_.ScriptStackTrace)) { write-log -message "$($_.ScriptStackTrace)" -consoleForeground Red }
    }   
}

function UpdateSubmittedCalculatedField ($web) {
	#Variables
	$ListName="ApplicationFacilityLookup"
	$CalculatedColumnName="SubmittedApplications"
	
	#Get the List
	$list = $web.Lists.TryGetList($ListName)
    if ($list -ne $null) {
		if ($list.Fields.ContainsFieldWithStaticName("SubmittedApplications")) {
			#Get the column
			$CalculatedCol = $List.Fields.GetField($CalculatedColumnName)
			#Set Formula for calculated column 
			$CalculatedCol.Formula="=IF(AND(OR([Application Status]=""Submitted"",[Application Status]=""Under Review""), ISBLANK(MovedToFacility)),[Study Title],"""")"
			$CalculatedCol.Update()
		}
	}
}

#This is to test the driver contains a $siteUrl
#$siteUrl="https://DNS.URL/sites/IRBApplications/";
$w = Get-SPWeb $siteUrl;
GetAllWebs($siteUrl)
   