<#

.SYNOPSIS
    reports all Site and List Workflows from SharePoint.

.DESCRIPTION
    Loops through all the webs, building a list of all the workflows present and prints the subscription and 
    definition from the workflow manager.

.EXAMPLE
    #when run from deploymentDriver.ps1
    Run-Script 450 getWorkflows.V3.ps1


.EXAMPLE
    #when run from command line
    .\getWorkflows.V3.ps1
#>
$StopWatch = [System.Diagnostics.Stopwatch]::StartNew()
#$url = "https://DNS.URL/sites/IRBApplications"

if ((get-module | Where-Object({$_.Name -eq 'RAMS_Module_Util'}) ) -eq $null) {
    if ($Global:diretoryName -eq $null) { 
        $Global:diretoryName = "D:\RAMS-2.3.0\LogFiles"
        $Global:logFileName = "getWorkflows.V3.log"
        Import-Module .\module\RAMS_Module_Util.psd1
    }
}

$url = (Get-SiteWeb).Url
$site=Get-SPSite($url);
$deployments = New-Object System.Collections.ArrayList
$subscriptions = New-Object System.Collections.ArrayList
$featureToDelete = @{}

    #write-log -message "Web`tDefinition.DisplayName`tSubscriptionName`tSPDConfig.StartOnCreate`tSPDConfig.StartManually`tSPDConfig.StartOnChange`tWSPublishState" -consoleForeground Cyan

foreach($web in $site.AllWebs){
    #write-log -message "Workflows in web $web" -consoleForeground Yellow
    $wfm = New-object Microsoft.SharePoint.WorkflowServices.WorkflowServicesManager($web)
    $wfds = $wfm.GetWorkflowDeploymentService()
	$wfss =$wfm.GetWorkflowSubscriptionService()
    #$wfis=$wfm.GetWorkflowInstanceService()

    #write-log -message " " -consoleForeground Yellow
    #write-log -message "Workflow Subscriptions" -consoleForeground Yellow
    $wfDefs = $wfss.EnumerateSubscriptions()
    foreach ($wfDef in $wfDefs){
        #$wfDef.properties
        #$hash = @{"[Definition.DisplayName]"=$wfDef.properties['Definition.DisplayName'];"[SubscriptionName]"=$wfDef.properties['SubscriptionName'];"[WSPublishState]"=$wfDef.properties['WSPublishState'];"[SPDConfig.StartOnCreate]"=$wfDef.properties['SPDConfig.StartOnCreate'];"[SPDConfig.StartOnChange]"=$wfDef.properties['SPDConfig.StartOnChange'];"[SPDConfig.StartManually]"=$wfDef.properties['SPDConfig.StartManually']}
        #$coll = @{"[$item]",
        #New-Object PSObject -Property $hash | Select-Object -Property Definition.DisplayName, SubscriptionName, SPDConfig.StartOnCreate, SPDConfig.StartManually, SPDConfig.StartOnChange, WSPublishState | Sort Definition.DisplayName | Format-Table -Wrap
        #write-log -message "$($web)`t$($wfDef.properties['Definition.DisplayName'])`t$($wfDef.properties['SubscriptionName'])`t$($wfDef.properties['SPDConfig.StartOnCreate'])`t$($wfDef.properties['SPDConfig.StartManually'])`t$($wfDef.properties['SPDConfig.StartOnChange'])`t$($wfDef.properties['WSPublishState'])" -consoleForeground Gray
        #$wfds.DeleteDefinition($wfDef.Id)
        $output = New-Object -TypeName "System.Object";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "WebName" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "DisplayName" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "DefinitionId" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "Id" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "StatusFieldName" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "pdGUID" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "ActivatedListName" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "WSPublishState" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "WSEnabled" -Value "";
		$output.WebName = $web.Name
		$output.DisplayName = $wfDef.Name
		$output.DefinitionId = $wfDef.DefinitionId
		$output.Id = $wfDef.Id
		$output.StatusFieldName = $wfDef.StatusFieldName
		$output.pdGUID = $wfDef.PropertyDefinitions['GUID']
		$output.ActivatedListName = $wfDef.PropertyDefinitions['Microsoft.SharePoint.ActivationProperties.ListName']
		$output.WSPublishState = $wfDef.PropertyDefinitions['WSPublishState']
		$output.WSEnabled = $wfDef.PropertyDefinitions['WSEnabled']
        $subscriptions.Add($output) | Out-Null

        $featureToDelete[$wfDef.Name] = $wfDef.DefinitionId  
        
        <#
        $wfss.DeleteSubscription($wfDef.Id)
        if($wfss.GetSubscription($wfDef.Id) -ne $null) {
            write-log -message " Delete subscription of $($wfDef.Name) on site $($web.Name) FAILED" -consoleForeground Red
        } else {
            write-log -message " Delete subscription of $($wfDef.Name) on site $($web.Name) SUCCEEDED" -consoleForeground Green
        }
        #>

    }

    $wfDefs = $wfds.EnumerateDefinitions($false)
    #write-log -message "Workflow Deployments" -consoleForeground Yellow
    foreach ($wfDef in $wfDefs){
        #$wfDef.properties
        #$hash = @{"[Definition.DisplayName]"=$wfDef.properties['Definition.DisplayName'];"[SubscriptionName]"=$wfDef.properties['SubscriptionName'];"[WSPublishState]"=$wfDef.properties['WSPublishState'];"[SPDConfig.StartOnCreate]"=$wfDef.properties['SPDConfig.StartOnCreate'];"[SPDConfig.StartOnChange]"=$wfDef.properties['SPDConfig.StartOnChange'];"[SPDConfig.StartManually]"=$wfDef.properties['SPDConfig.StartManually']}
        #$coll = @{"[$item]",
        #New-Object PSObject -Property $hash | Select-Object -Property Definition.DisplayName, SubscriptionName, SPDConfig.StartOnCreate, SPDConfig.StartManually, SPDConfig.StartOnChange, WSPublishState | Sort Definition.DisplayName | Format-Table -Wrap
        #write-log -message "$($web)`t$($wfDef.properties['Definition.DisplayName'])`t$($wfDef.properties['SubscriptionName'])`t$($wfDef.properties['SPDConfig.StartOnCreate'])`t$($wfDef.properties['SPDConfig.StartManually'])`t$($wfDef.properties['SPDConfig.StartOnChange'])`t$($wfDef.properties['WSPublishState'])" -consoleForeground Gray
        #$wfds.DeleteDefinition($wfDef.Id)
		$output = New-Object -TypeName "System.Object";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "WebName" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "DisplayName" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "DefinitionId" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "SubscriptionName" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "SubscriptionId" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "StartOnCreate" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "StartOnChange" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "StartManually" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "WSPublishState" -Value "";
		Add-Member -InputObject $output -MemberType NoteProperty -Name "GUID" -Value "";
		$output.WebName = $web.Name
		$output.DisplayName = $wfDef.properties['Definition.DisplayName']
		$output.DefinitionId = $wfDef.properties['Definition.Id']
		$output.SubscriptionName = $wfDef.properties['SubscriptionName']
		$output.SubscriptionId = $wfDef.properties['SubscriptionId']
		$output.StartOnCreate = $wfDef.properties['SPDConfig.StartOnCreate']
		$output.StartOnChange = $wfDef.properties['SPDConfig.StartOnChange']
		$output.StartManually = $wfDef.properties['SPDConfig.StartManually']
		$output.WSPublishState = $wfDef.properties['WSPublishState']
		$output.guid = $wfDef.properties['GUID']
        $deployments.Add($output) | Out-Null
        
        $featureToDelete[($wfDef).properties['Definition.DisplayName']] = $wfDef.properties['Definition.Id']  
        
        <#
        $wfds.DeleteDefinition(($wfDef).properties['Definition.Id'])
        if($wfds.GetDefinition(($wfDef).properties['Definition.Id']) -ne $null) {
            write-log -message " Delete definition of $($wfDef.properties['Definition.DisplayName']) on site $($web.Name) FAILED" -consoleForeground Red
        } else {
            write-log -message " Delete definition of $($wfDef.properties['Definition.DisplayName']) on site $($web.Name) SUCCEEDED" -consoleForeground Green
        }
        #>
    }
 
}

$featureToDelete["Application Status Under Review WF"] = '878a4805-2182-4c1c-b66e-6447cf75313e'
$featureToDelete["Application Type Change WF"] = '784aa20f-91e0-4a0e-af36-37827180855a'
$featureToDelete["Approved Application Submitted Notification WF"] = '62f47062-4bf5-4ba8-81e8-3ae186bc66f6'  
$featureToDelete["Copy Agenda To Minutes WF.wsp"] = '4ba23df0-9051-43ca-b475-490d59051cd8'

write-log -message " " -consoleForeground White
write-log -message "Workflow Deployments" -consoleForeground Yellow
$deploymentsFile = ".\wfDeployments.csv"
$deployments | Sort WebName, DisplayName | format-table -property WebName, DisplayName, DefinitionId, guid, SubscriptionName,SubscriptionId -AutoSize
$deployments | Select-Object WebName, DisplayName, DefinitionId, guid, SubscriptionName, SubscriptionId, StartOnCreate, StartOnChange, StartManually, WSPublishState | Export-Csv -Path $deploymentsFile -Encoding ascii -NoTypeInformation
write-log -message "Workflow Deployments file written to $deploymentsFile" -consoleForeground Yellow
    
write-log -message " " -consoleForeground White
write-log -message "Workflow Subscriptions" -consoleForeground Yellow
$subscriptionsFile = ".\wfSubscriptions.csv"
$subscriptions | Sort WebName, DisplayName | format-table -property WebName, DisplayName, DefinitionId, Id, StatusFieldName,pdGUID, ActivatedlistName,WSPublishState,WSEnabled -AutoSize
$subscriptions | Select-Object WebName, DisplayName, DefinitionId, Id, StatusFieldName,pdGUID, ActivatedlistName,WSPublishState,WSEnabled | Export-Csv -Path $subscriptionsFile -Encoding ascii -NoTypeInformation
write-log -message "Workflow Subscriptions file written to $subscriptionsFile" -consoleForeground Yellow
<#
write-log -message " " -consoleForeground White
write-log -message "Workflow Features To Delete before removal" -consoleForeground Yellow
Get-SPFeature -Limit ALL | Where-Object {$_.Scope -eq $null } | Sort Scope, DisplayName | ft -AutoSize
Get-SPUserSolution -Site $site.Url | Sort Name | ft -AutoSize
foreach($ftd in $featureToDelete.Keys){
    write-log -message "$ftd : $($featureToDelete[$ftd])" -consoleForeground White
       
    write-log -message "  Remove-WorkFlow Feature: $ftd on site: $($site.Url)" -consoleForeground Yellow
    write-log -message "    Disable-SPFeature $ftd $($featureToDelete[$ftd])" -consoleForeground Gray
    Disable-SPFeature -Identity $featureToDelete[$ftd] -Url $site.Url -Confirm:$false -Force -ErrorAction SilentlyContinue  
        
    $checkSPFeature = Get-SPFeature -Limit ALL | Where-Object {$_.DisplayName -eq "$ftd"+"ListInstances" } 
    if($checkSPFeature -ne $null){
        write-log -message "      After Disable-SPFeature: The feature: $ftd is not disabled" -consoleForeground Red
    } else {
        write-log -message "      After Disable-SPFeature: The feature: $ftd is not found" -consoleForeground Green
    }
        
    $spus = Get-SPUserSolution -Site $site.Url -Identity "$ftd.wsp" -ErrorAction SilentlyContinue
    $spusName = $spus.Name
    $spusSolutionId = $spus.SolutionId
    if($spus -ne $null) {
        write-log -message "    Uninstall-SPUserSolution $spusName $spusSolutionId" -consoleForeground Gray
        Uninstall-SPUserSolution -Identity $spusName -Site $site.Url -Confirm:$false 
        
        $checkSPUserSolution = Get-SPUserSolution -Site $site.Url -Identity $spusName
        if($checkSPUserSolution -eq $null) {
            write-log -message "      After Uninstall: The SPUserSolution: $spusName is not found" -consoleForeground Red
        } else {
            if($checkSPUserSolution.Status -ne "Activated"){
                write-log -message "      After Uninstall: The SPUserSolution: $spusName is not Activated" -consoleForeground Green
            } else {
                write-log -message "      After Uninstall: The SPUserSolution: $spusName is still Activated" -consoleForeground Red
            }
        }

        write-log -message "    Remove-SPUserSolution $spusName" -consoleForeground Gray 
        Remove-SPUserSolution -Identity $spusName -Site $site -Confirm:$false 
            
        $checkSPUserSolution = Get-SPUserSolution -Site $site.Url -Identity $spusName -ErrorAction SilentlyContinue
        if($checkSPUserSolution -ne $null){
            write-log -message "      After Remove: The SPUserSolution: $spusName is not Removed" -consoleForeground Red
        } else {
            write-log -message "      After Remove: The SPUserSolution: $spusName is Removed" -consoleForeground Green
        }

    } else {
        write-log -message "Get-SPUserSolution did not find solution $ftd" -consoleForeground Magenta
    }
       
}#>
write-log -message "Workflow Features To Delete after removal" -consoleForeground Yellow
Get-SPFeature -Limit ALL | Where-Object {$_.Scope -eq $null } | Sort Scope, DisplayName | ft -AutoSize
Get-SPUserSolution -Site $site.Url | Sort Name | ft -AutoSize

$StopWatch.Stop()
$StopWatch.Elapsed