<#
.SYNOPSIS
    Utility and Testing script to create an Application List item
    
.DESCRIPTION
    Used to work out the defails for creating an application list item.
    
.EXAMPLE
    #when run from the powershell command prompt.
    .\CreateApplicationListItem.v2.ps1
#>
if ((Get-PSSnapin "Microsoft.SharePoint.PowerShell" -ErrorAction SilentlyContinue) -eq $null) {
    Add-PSSnapin "Microsoft.SharePoint.PowerShell"
}

### ENVIRONMENT SETTINGS
$user = "domain\user"
$pass = "password"
$ListName = "Application"
$url = "https://DNS.URL:PORT/sites/IRBApplications"
 
### TOGGLE DEBUG MODE
$debug = $FALSE
 
### DO NOT MODIFY
$headers = @{accept = "application/json; odata=verbose"}
$formDigest = $null
$secPass = ConvertTo-SecureString $pass -AsPlainText -Force
$cred = New-Object System.Management.Automation.PSCredential ($user, $secPass)
 
function SetFormDigest() {
    $response = PostRequest ("/_api/contextinfo") $null
    $formDigest = $response.d.GetContextWebInformation.FormDigestValue
    $headers.Add("X-RequestDigest", $formDigest);
    
    if ($debug) {
        Write-Host "Form Digest: " $formDigest
    }
}
 
function Request ($endpoint, $body, $method) {
    if ($debug) {
        Write-Host "Endpoint: $endpoint, Method: $method, Cred:" $cred.UserName -BackgroundColor Green -ForegroundColor Black
        Write-Host "Header Keys:" $headers.Keys -BackgroundColor DarkGreen -ForegroundColor Gray
        Write-Host "Header Values:" $headers.Values -BackgroundColor DarkGreen -ForegroundColor Gray
        Write-Host "Body Keys:" $body.Keys -BackgroundColor DarkGreen -ForegroundColor Gray
        Write-Host "Body Values:" $body.Values -BackgroundColor DarkGreen -ForegroundColor Gray
    }
    try
    {
        return Invoke-RestMethod -Uri ($url+$endpoint) -Headers $headers -Method $method -Body $body -Credential $cred -ContentType "application/json;odata=verbose"
    }
    catch
    {
        Failure
    }
}

function Failure {
#$global:helpme = $body
#$global:helpmoref = $moref
$global:result = $_.Exception.Response.GetResponseStream()
$global:reader = New-Object System.IO.StreamReader($global:result)
$global:responseBody = $global:reader.ReadToEnd();
Write-Host -BackgroundColor:Black -ForegroundColor:Red "Status: A system exception was caught."
Write-Host -BackgroundColor:Black -ForegroundColor:Red $global:responsebody
Write-Host -BackgroundColor:Black -ForegroundColor:Red 'Request Body:'$body
break
}

 
function GetRequest ($endpoint, $body) {
    return Request $endpoint $body ([Microsoft.PowerShell.Commands.WebRequestMethod]::Get)
}
 
function PostRequest ($endpoint, $body) {
    return Request $endpoint $body ([Microsoft.PowerShell.Commands.WebRequestMethod]::Post)
}
 
function CreateListITem($ListName, $itemTitle) {
    Write-Host "Creating Item'$itemTitle'" 
    
    $response = PostRequest ("/_api/web/lists/getbytitle('" + $ListName + "')/items") (ConvertTo-Json @{ 
        __metadata = @{ type= 'SP.Data.ApplicationListItem' }
        Title = $itemTitle})        
}
 
 
## Script Begin ##
 
SetFormDigest
$listitemTitle = "AnItem-" + (Get-Date).ToString() 
CreateListITem $ListName $listitemTitle

