<#
.SYNOPSIS
    Utility and Testing script to retrieve SPUserSolution information

.DESCRIPTION
    If the SolutionName is empty, then all SPUserSolutions are retrieved, otherwise information about the specific 
    solutionName is retrieved and displayed. 

.PARAMETER SolutionName
    [String] The name of the solution to get informaiton about. If "" or not provided, all solutions are reported.
    
.PARAMETER WebApplicationUrl
    [String] The URL of the webApplication.

.EXAMPLE
    #when run from the powershell command prompt.
    #get information about all solutionNames
    .\Get-SPUserSolutionInWebApplication.ps1 -WebApplicationUrl "https://DNS.URL/sites/IRBApplication" 

.EXAMPLE
    #when run from the powershell command prompt.
    #get information about all solutionNames
    .\Get-SPUserSolutionInWebApplication.ps1 -WebApplicationUrl "https://DNS.URL/sites/IRBApplication" -SolutionName ""

.EXAMPLE
    #when run from the powershell command prompt.
    #get information about a specific solutionName
    .\Get-SPUserSolutionInWebApplication.ps1 -WebApplicationUrl "https://DNS.URL/sites/IRBApplication" -SolutionName "rwf_SetDocumentTitleToFilename"

#>
param (
    [Parameter(Mandatory=$false, HelpMessage='Solution Name')]
    [string]$SolutionName="",
    [Parameter(Mandatory=$false, HelpMessage='Solution Name')]
    [string]$WebApplicationUrl=""
)

$memoryAssignment = Start-SPAssignment;
$numberOfSolutionsFound = 0;
$webApplication = Get-SPWebApplication -Identity $WebApplicationUrl -ErrorAction SilentlyContinue -AssignmentCollection $memoryAssignment;
if($webApplication -ne $null) {
    #enumerate through site collections in web application
    $allSites = Get-SPSite -WebApplication $webApplication -Limit ALL -Confirm:$false -AssignmentCollection $memoryAssignment;
    foreach($checkSite in $allSites) {
        #Write-Output "Checking Site " $checkSite.Url " for solution " $SolutionName;
        if($SolutionName -eq "") {
            $checkSolutions = Get-SPUserSolution -Site $checkSite -AssignmentCollection $memoryAssignment;
            foreach($solution in $checkSolutions) {
                $output = New-Object -TypeName "System.Object";
                Add-Member -InputObject $output -MemberType NoteProperty -Name "Solution" -Value "";
                Add-Member -InputObject $output -MemberType NoteProperty -Name "SiteCollection" -Value "";
                $output.Solution = $solution;
                $output.SiteCollection = $checkSite;
                Write-Output -InputObject $output;
                $numberOfSolutionsFound++
            }
        } else {
            $checkSolution = Get-SPUserSolution -Identity $SolutionName -Site $checkSite -ErrorAction SilentlyContinue -AssignmentCollection $memoryAssignment;
            if($checkSolution -ne $null) {
                $output = New-Object -TypeName "System.Object";
                Add-Member -InputObject $output -MemberType NoteProperty -Name "Solution" -Value "";
                Add-Member -InputObject $output -MemberType NoteProperty -Name "SiteCollection" -Value "";
                $output.Solution = $checkSolution;
                $output.SiteCollection = $checkSite;
                Write-Output -InputObject $output;
                $numberOfSolutionsFound++
            }
        }
    }
}

Write-Output "Found $numberOfSolutionsFound Instances of Solution $SolutionName";
Stop-SPAssignment $memoryAssignment;
