﻿<#

.SYNOPSIS
    Utility and Testing script retrieve system configuration information

.DESCRIPTION
    Creates a text file with Site information and databases used
    
.EXAMPLE
    #when run from command line
    .\misc\get-siteinfo.ps1
#>
If ((Get-PSSnapIn -Name Microsoft.SharePoint.PowerShell -ErrorAction SilentlyContinue) -eq $null ) { 
    Add-PSSnapIn -Name Microsoft.SharePoint.PowerShell 
} 

$rundate = Get-Date -UFormat "%Y%m%d%H%M"
$filename = "SystemInfo_$env:COMPUTERNAME.$rundate.txt"
$webAppInfo = New-Object System.Collections.ArrayList
$sitesInfo = New-Object System.Collections.ArrayList

"System Information for $env:COMPUTERNAME"  | Out-File -FilePath $filename -Encoding "ASCII" -Force
" "  | Out-File -FilePath $filename -Encoding "ASCII" -Append

"GET-SPSITE"  | Out-File -FilePath $filename -Encoding "ASCII" -Append
$sites = Get-SPSite -Limit All 
$sites | Sort Url | Format-Table -AutoSize | Out-File -FilePath $filename -Encoding "ASCII" -Append
foreach ($site in $sites) {
    try {
        foreach ($web in $site.AllWebs) {
            $output = New-Object -TypeName "System.Object";
	        Add-Member -InputObject $output -MemberType NoteProperty -Name "DisplayName" -Value "$($web.Title)";
	        Add-Member -InputObject $output -MemberType NoteProperty -Name "Url" -Value "$($web.Url)";
            try {
                $spcdb = Get-SPContentDatabase -Site $($web.Site.Url)
                Add-Member -InputObject $output -MemberType NoteProperty -Name "DBName" -Value "$($spcdb.Name)";
            } catch {
                Add-Member -InputObject $output -MemberType NoteProperty -Name "DBName" -Value "$_.Exception.Message";
            }
            $sitesInfo.Add($output) | Out-Null
        }
    } catch {
    }
}
$sitesInfo | Sort Url, DisplayName | format-table -property DisplayName, DBName, Url -AutoSize | Out-File -FilePath $filename -Encoding "ASCII" -Append


"GET-SPWEBAPPLICATION"  | Out-File -FilePath $filename -Encoding "ASCII" -Append
get-spwebapplication | Sort Url, DisplayName | Format-Table -AutoSize | Out-File -FilePath $filename -Encoding "ASCII" -Append
$webapps = get-spwebapplication
foreach ($webapp in $webapps) {
    $output = New-Object -TypeName "System.Object";
	Add-Member -InputObject $output -MemberType NoteProperty -Name "DisplayName" -Value "$($webapp.DisplayName)";
	Add-Member -InputObject $output -MemberType NoteProperty -Name "Url" -Value "$($webapp.Url)";
    $spcdb = Get-SPContentDatabase -Site $($webapp.Url)
	Add-Member -InputObject $output -MemberType NoteProperty -Name "DBName" -Value "$($spcdb.Name)";
    #"$($webapp.Url) uses $($spcdb.Name)" | Out-File -FilePath $filename -Encoding "ASCII" -Append
    $webAppInfo.Add($output) | Out-Null
}
$webAppInfo | Sort Url, DisplayName | format-table -property DisplayName, DBName, Url -AutoSize | Out-File -FilePath $filename -Encoding "ASCII" -Append


#Get all databases currently used by the farm
"GET-SPDATABASE"  | Out-File -FilePath $filename -Encoding "ASCII" -Append
Get-SPDatabase | Sort-Object Name  | Format-Table -AutoSize | Out-File -FilePath $filename -Encoding "ASCII" -Append

#Get all content databases currently used
"GET-SPCONTENTDATABASE"  | Out-File -FilePath $filename -Encoding "ASCII" -Append
Get-SPContentDatabase | Sort-Object Name | Format-Table -AutoSize | Out-File -FilePath $filename -Encoding "ASCII" -Append

Write-Host "Done. SiteInfo output is in $filename." -ForegroundColor Green