<#
.SYNOPSIS
    Utility and Testing script to retrieve List information

.DESCRIPTION
    Retrieves and reports on a specified list, provides the InternalName, StaticName, Title, Required, DefaultValue, 
    Type, LookupList, LookupField, Hidden, CanBeDeleted. Having a wide screen to view the information is helpful. This 
    is a good way to determine the internalNames and StaticNames for a give list and siteColumn.

.PARAMETER ListName
    [String] The name of the list to be reported. Defaults to "Shared Documents"
    
.PARAMETER Url
    [String] The URL of the site collection. Defaults to "http://DNS.URL/sites/IRBApplications"

.PARAMETER subsiteName
    [String] Name of the subsite where the list resides. This is added to the URL to determine the subsite URL. 
    Defaults to ""

.EXAMPLE
    #when run from the powershell command prompt.
    #List the siteColumn information in the Application List at the Site Collection level
    .\GetListColumns.ps1 -ListName "Application" -Url "https://DNS.URL/sites/IRBApplication" 

.EXAMPLE
    #when run from the powershell command prompt.
    #List the siteColumn information in the Committee Calendar List at the Facility Subsite level
    .\GetListColumns.ps1 -ListName "Committee Calendar" -Url "https://DNS.URL/sites/IRBApplication" -subsiteName "Asheville"

#>
[CmdletBinding()]
Param(
   [Parameter(Mandatory=$false)]
   [string]$ListName = "Shared Documents",

   [Parameter(Mandatory=$false)]
   [string]$Url = "http://DNS.URL/sites/IRBApplications",

   [Parameter(Mandatory=$false)]
   [string]$subsiteName = ""
)

if ((Get-PSSnapin "Microsoft.SharePoint.PowerShell" -ErrorAction SilentlyContinue) -eq $null) {
    Add-PSSnapin "Microsoft.SharePoint.PowerShell"
}
$sScriptDir = Split-Path -parent $MyInvocation.MyCommand.Path 
if ((get-module | Where-Object({$_.Name -eq 'RAMS_Module_Util'}) ) -eq $null) {
    Import-Module $sScriptDir\..\module\RAMS_Module_Util.psd1 
}

$lookupGuids = @(
)
$listInfo = @(
)
$siteUrl = "$Url"
if ($subsiteName) { 
    $siteUrl += "/$subsiteName" 
}
#$site = Get-SPWeb $siteURL
#$SpSite = Get-SpSite -Identity $siteURL
#$w = Get-SiteWeb
$w = Get-SPWeb $siteUrl
$list = $w.Lists[$ListName]
Write-Host "$($list.Title)" -ForegroundColor Yellow
#$list.fields | select Title, InternalName, Type, Hidden, CanBeDeleted | sort title | ft -AutoSize 
#$list.fields | ?{$_.Type -eq "Lookup"} | Sort Title | select Title, InternalName, StaticName, Type, LookupList, LookupField, Hidden, CanBeDeleted | sort title | ft -AutoSize 
$list.fields | Sort InternalName, Title | select InternalName, StaticName, Title, Required, DefaultValue, Type, LookupList, LookupField, Hidden, CanBeDeleted | % { 
    if (($_.LookupList) -and ($_.LookupList -match '{\w{8}-\w{4}-\w{4}-\w{4}-\w{12}}')) {
        $lookupGuids += $_.LookupList
    }
    $_ } | ft -Wrap


#Get-SPSite http://DNS.URL/sites/IRBApplications |Get-SPWeb -Limit ALL | %{$_.Lists} | ?{$_.ID -eq "db7be6af-e7ce-414a-81d1-4634e0199511"} | ft Title, ParentWebURL, RootFolder
foreach ($g in $lookupGuids) {
    $listInfo += $w.Lists[[GUID]($g)] 
}
$listInfo | Sort ID | ft Title, ID, ParentWebURL, RootFolder


#%{$w.Lists} | Sort Title | ft Title, ID, ParentWebURL, RootFolder 
#if($w.Webs.Count -gt 0) {
#    foreach($web in $w.Webs) {
#       #%{$web.Lists} | ?{$_.ID -eq "db7be6af-e7ce-414a-81d1-4634e0199511"} | ft Title, ParentWebURL, RootFolder
#       %{$web.Lists} | Sort Title | ft Title, ID, ParentWebURL, RootFolder 
#    }
#}