<#
.SYNOPSIS
    Utility and Testing script to retrieve a list of security groups and all the users in each group

.DESCRIPTION
    Builds a csv list of all SharePoint security groups and the users in each group. The format is built so that 
    the output can be run directly to remove all users from the security groups, using Import-RAMSUsers.ps1. You will 
    probably want to remove the people that you want to keep in the system and remove the standard SharePoint groups
    from the list. The output file is named "$($webTitle).SecurityGroupUsers.$($rundate).csv" and will be located in 
    the current directory. 

.EXAMPLE
    #when run from the powershell command prompt.
    .\GetSecurityGroupUsers.ps1 

#>
If ((Get-PSSnapIn -Name Microsoft.SharePoint.PowerShell -ErrorAction SilentlyContinue) -eq $null )  { 
    Add-PSSnapIn -Name Microsoft.SharePoint.PowerShell 
} 

if ((Get-Module -Name RAMS_Module_Util) -ne $null) {
    Remove-Module -Name RAMS_Module_Util
}

try {
    if ($env:COMPUTERNAME -match "VAPH") {
        Import-Module .\module\RAMS_Module_Util.psd1 -DisableNameChecking -Global
    }
    else {
        Import-Module ..\UtilityScripts\RAMS_Module_Util.psd1 -DisableNameChecking -Global
    }
} catch {
    #write-host "Unable to load RAMS_Module_Util.psd1" -ForegroundColor Red
    throw "Unable to load RAMS_Module_Util.psd1"
}


#$site = Get-SPSite "https://DNS.URL/sites/IRBApplications"
#$web = $site.OpenWeb()
$web = Get-SiteWeb
$webTitle = $web.Title.Replace(" ","")
$groups = $web.sitegroups
$groupMembers = New-Object System.Collections.ArrayList
$rundate = Get-Date -UFormat "%Y%m%d%H%M"
$filename = "$($webTitle).SecurityGroupUsers.$($rundate).csv"


#Write-Host "Security Group`tPerson`tAction" -foregroundcolor cyan
foreach ($grp in $groups) {
    #"Group: " + $grp.name;
    $groupName = $grp.name
    
    #write-host "Group: " $groupName   -foregroundcolor green
    foreach ($user in $grp.users) {
            $userDisplayName = $user.DisplayName.Trim()
            $output = New-Object -TypeName "System.Object";
            Add-Member -InputObject $output -MemberType NoteProperty -Name "Security Group" -Value $groupName
            Add-Member -InputObject $output -MemberType NoteProperty -Name "Person" -Value $userDisplayName
            Add-Member -InputObject $output -MemberType NoteProperty -Name "Action" -Value "Remove"
            $groupMembers.Add($output) | Out-Null
            #write-host "$groupName`t$userDisplayName`tRemove"    -foregroundcolor cyan
    }
}
Write-Output -inputObject $groupMembers -NoEnumerate | Export-CSV -Path $filename -NoTypeInformation
Write-Host "$filename contains the user information." -ForegroundColor Green
Write-Host " " -ForegroundColor White
