if((Get-Module -Name RAMS_Module_Util) -eq $null) {
    Import-Module .\RAMS_Module_Util.psd1 
}
$rundate = Get-Date -UFormat "%Y%m%d%H%M"
$Global:cleanLogFileName = "CleanHistory_$env:COMPUTERNAME.$rundate.log"
if ($Global:diretoryName -eq $null) {
    $Global:diretoryName = Split-Path -Path $MyInvocation.MyCommand.Path -Parent
}
$cleanHistoryPath = join-path -path $Global:diretoryName -childpath $Global:cleanLogFileName

Set-StrictMode -Version Latest

$ArrayList = New-Object System.Collections.ArrayList

function Get-ColumnValueFromAList ($Site, $subSite, $filterDate, $listUrl, $listName, $listColumnName) {
    #get a collection of ids
    $itemsToDelete = New-Object System.Collections.ArrayList
    $list = Get-SPList -web $Site -Name $listName -Url $listUrl -subWeb $subSite
    #get application list
    if($list -ne $null) {
        #Get all items in this list and save them to a variable
        $items = $list.items
        $itemCount = 0
        #Go through all items
        Write-log -message "Total Items in the $($list.EntityTypeName) : $($items.Count)" -consoleForeground Green -Path $cleanHistoryPath
        foreach($item in $items) {
            if($item["Created"] -lt $filterDate) { 
                #add each item id to the delete list  
                Write-log -message "Add item $itemCount  from the list for Study: $($item["Title"]) on $($item["Created"])" -consoleForeground Cyan -Path $cleanHistoryPath
                $itemsToDelete.Add($item[$listColumnName])
                $itemCount ++;
            }
        }
        #now start deleting those items
        if($itemCount -eq 0) {
            Write-log -message "Nothing to delete, count: $itemCount" -consoleForeground yellow -Path $cleanHistoryPath
         return
        }
       Write-log -message "Total items to be deleted $itemCount" -consoleForeground yellow -Path $cleanHistoryPath
    } else {
        Write-log -message "No list found by the name: $listUrl" -consoleForeground red -Path $cleanHistoryPath
    }
    return $itemsToDelete
}

function Remove-DataFromAListByColumn ($Site, $subSite, $ColumnSet, $listUrl, $listName, $listColumnName) {
    #get a collection of ids
    $itemsToDelete = New-Object System.Collections.ArrayList
    $list = Get-SPList -web $Site -Name $listName -Url $listUrl -subWeb $subSite
    #get application list
    if($list -ne $null) {
        #Get all items in this list and save them to a variable
        $items = $list.items
        $listTitle = $list.Title
        $itemCount = 0
        #Go through all items
        Write-log -message "Total Items in the $($list.EntityTypeName) : $($items.Count)" -consoleForeground Green -Path $cleanHistoryPath
        foreach($item in $items) {
            foreach($col in $ColumnSet) {
                $x = $item.Url 
                if($x.IndexOf("/Study") -gt 0) {
                    $studyId = $x.Substring($x.IndexOf("/")+1,$x.IndexOf("/Study")-$x.IndexOf("/")-1)
                    if($studyId -eq $col) { 
                        if ($item.Title -ne $null) {
                            $itemDescription = $item.Title
                        } elseif ($item.Name -ne $null ) {
                            $itemDescription = $item.Name
                        } else {
                            $itemDescription = "Unknown Title or Name"
                        }
                        #add each item id to the delete list  
                        Write-log -message "$itemCount. Add item.Id $($item.Id) from the list $listTitle for Study: $itemDescription on $($item["Created"])" -consoleForeground Cyan -Path $cleanHistoryPath
                        $itemsToDelete.Add($item.ID)
                        $itemCount ++;
                    }
                }
            }
        }
        #now start deleting those items
        if($itemCount -eq 0) {
            Write-log -message "Nothing to delete, count: $itemCount" -consoleForeground Yellow -Path $cleanHistoryPath
         return
        }
        Write-log -message "Total items to be deleted $itemCount" -consoleForeground Yellow -Path $cleanHistoryPath
        $deleteItemCount = 0
        foreach($itemToDelete in $itemsToDelete) {
            Write-log -message "$($deleteItemCount) of $($itemCount). Deleting item.Id $itemToDelete from $listTitle list." -consoleForeground Yellow -Path $cleanHistoryPath
            $items.DeleteItemById($itemToDelete);
            deleteItemCount++
        }
        $items.Update();
        $list.Update();
        Write-log -message "Total number of items in $listTitle after delete: $($list.items.Count)" -consoleForeground Green -Path $cleanHistoryPath
    } else {
        Write-log -message "No list found by the name: $listUrl" -consoleForeground red -Path $cleanHistoryPath
    }
    return $itemsToDelete
}

function Remove-RAMSHistoryData ($cleanDate, $dbServer) {
    #get site collection
    #$site = Get-SPSite -Limit All | Select-String IRBApplications
    $site= Get-SiteURL
    $x = $site.ToString();
    $url = $x.Substring($x.IndexOf("=")+1)
    #$w = Get-SPWeb $url
    $w = Get-SiteWeb

    #filter by days
    $filterPriorDate = $cleanDate
    write-log -message "Delete data before $filterPriorDate" -consoleForeground magenta -Path $cleanHistoryPath

    #Delete Application list for older studies.
    $listUrl = $url + "/Lists/Application/AllItems.aspx"
    $listOfStudies = Get-ColumnValueFromAList -Site $w -filterDate $filterPriorDate -listUrl $listUrl -listColumnName "Study_ID"

    Remove-DataFromAList -Site $w -filterDate $filterPriorDate -listUrl $listUrl

    #Delete workflow task list
    $listUrl = $url + "/WorkflowTasks/AllItems.aspx"
    Remove-DataFromAList -Site $w -filterDate $filterPriorDate -listUrl $listUrl

    #Delete Shared Docs for the same set of studies
    $listUrl = $url + "/Shared%20Documents/Forms/AllItems.aspx"
    Remove-DataFromAList -Site $w -filterDate $filterPriorDate -listUrl $listUrl
    Remove-DataFromAListByColumn -Site $w -ColumnSet $listOfStudies -listUrl $listUrl -listColumnName "Name"

    #delete items from list at sub-site level
    $listBucket = @(
        "FullBoardReviewCalendar",
        "CommitteeMinutes",
        "Application",
        "DataSharingRepositoryAgreements",
        "IACUC Calendar",
        "RDC Calendar",
        "SRSCalendar",
        "SC1Calendar",
        "SC2Calendar",
        "SC3Calendar",
        "Agenda",
        "ApplicationFacilitylookup",
        "Appointments",
        "CommitteeMembers",
        "CommitteeRoster",
        "CommitteeTopics",
        "CommitteeWorkflow",
        "Labs",
        "Property",
        "Reviews"
    );
  
    $formBucket = @(
        "IACUCDocuments",
        "RDCAgenda",
        "RDCDocuments",
        "RCOChecklists",
        "Checklists",
        "SRSDocuments",
        "Documents",
        "SC1Documents",
        "SC2Documents",
        "SC3Documents",
        "AnimalFacilityDocuments",
        "InvestigatorDocuments",
        "MeetingMinutes",
        "StudyReview",
        "WorkflowTasks"
    );

    foreach($sub in $w.Webs) {
        #Delete list data
        foreach($listEgg in $listBucket) {
            $listUrl = $sub.url + "/Lists/" + $listEgg + "/AllItems.aspx"
            Remove-DataFromAList -filterDate $filterPriorDate -listName $listEgg -listUrl $listUrl -subSite $sub
        }
        #Delete form data
        foreach($formEgg in $formBucket) {
            $listUrl = $sub.url + "/" + $formEgg + "/Forms/AllItems.aspx"
            Remove-DataFromAList -filterDate $filterPriorDate -listName $formEgg -listUrl $listUrl -subSite $sub
        }
    }
    #clean from sql server    
    $recAffected =  RunSQL-ReturnInt -sqlQuery "exec DataCleanup @cutoffdate='$cleandate'" -dbServer $dbServer   
    write-log -message "Total $recAffected Studies have been deleted from the RAMS user database" -consoleForeground yellow -Path $cleanHistoryPath
}

Export-ModuleMember Remove-RAMSHistoryData

<#
e.g. Remove-RAMSHistoryData -cleanDate "12/30/2015 12:56:20" -dbServer DNS
Set-Location .\module
New-ModuleManifest -Path .\RAMS_Module_CleanHistory.psd1 -ModuleVersion 1.1.0 -Author "Chita Nilak, ByLight" -RootModule .\RAMS_Module_CleanHistory.psm1 -Description "RAMS Utility Functions" -CompanyName "DNS" -Verbose 
cd..
if((Get-Module -Name RAMS_Module_CleanHistory) -ne $null) {
    Remove-Module -Name RAMS_Module_CleanHistory
}
try {
    Import-Module .\RAMS_Module_CleanHistory.psd1 
}
catch {
    Write-log -message "Host: $env:COMPUTERNAME is not a Server, SharePoint is not installed on this computer...ignore, information only." -consoleForeground yellow -Path $cleanHistoryPath
    #do nothing.
}

#>