Add-PSSnapin Microsoft.SharePoint.PowerShell

if ((get-module | Where-Object({$_.Name -eq 'RAMS_Module_Util'}) ) -eq $null) {
    Import-Module .\RAMS_Module_Util.psm1 -Verbose
}

$siteWeb = Get-SiteWeb


function Add-AnimalFacilityManagerGroups {
    #add new fields to the facility list to store new security groups
    #Animal Facility ManagersGroup
    Set-SiteColumn -web $siteWeb -sFieldDisplayName "Animal Facility Managers" -sFieldInternalName AnimalFacilityManagers -sFieldType User -sChoice AllUsers   -spFieldGroup "Animal Facility Managers Group"
    Add-SiteColumnToCT -web $siteWeb -ctName "Facility CT" -sFieldInternalName AnimalFacilityManagers -sFieldStaticName AnimalFacilityManagers

    #update facility list
    $facilityList = $siteWeb.GetListFromUrl("Lists/Facilities/AllItems.aspx")
    #update the view to include two new fields
    $view = $facilityList.Views | ? { $_.Title -eq 'All items' }
    $view.ViewFields.Add("AnimalFacilityManagers");
    $view.Update();

    #populate new fields, for each facility (per row) w/ new relevant security groups.
    foreach ($item in $facilityList.Items) {
        #facility name
        $_facilityName = $item["Title"]
        #populate the value for new groups
    	New-RAMSGroup -facility $_facilityName -newGroupName "Animal Facility Managers" -newGroupPermission "Edit" -groupOwnerSuffix "Local Site Administrators" -newGroupDescSuffix "Animal Facility Managers"
        $item["Animal Facility Managers"] = $siteWeb.SiteGroups["$_facilityName Animal Facility Managers"]
        #update
        $item.Update()
    }
}

Add-AnimalFacilityManagerGroups

